## This file is part of HamsiManager.
## 
## Copyright (c) 2010 Murat Demir <mopened@gmail.com>      
##
## Hamsi Manager is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
## 
## Hamsi Manager is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
## 
## You should have received a copy of the GNU General Public License
## along with HamsiManager; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

import sys
import os
from optparse import OptionParser, OptionGroup
import Variables
import Universals
import logging

myArgvs = []
isQuickMake = False
QuickMakeParameters = []
parser =None

def checkParameters():
    global isQuickMake, QuickMakeParameters, myArgvs, parser, optionList
    myArgvs = sys.argv
    isDontRun = False
    optionList = []
    parser = OptionParser(
    usage="%prog [options] [<arg1>...]", version="HamsiManager " + Variables.version, 

    epilog="""\
Copyright (c) 2010 Murat Demir <mopened@gmail.com> ,
HamsiManager is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.""")
    parser.add_option('-d', '--debug', help='Enable debugging output. '
                      'Chatty', action='store_const', const=logging.DEBUG,
                      dest='loggingLevel')
    optionList.append("d")
    optionList.append("debug")
    parser.add_option('-v', '--verbose', help='Enable informative output',
                      action='store_const', const=logging.INFO,
                      dest='loggingLevel')
    optionList.append("v")
    optionList.append("verbose")
    parser.add_option('--directory',
                      help='The current directory path. '
                      'Example : /home/yourname/someDirectory ')
    optionList.append("directory <directory>")
    parser.add_option('-s', '--sFileName',
                      help='The setting file name(or path). '
                      '"The settings directory path" + "SettingFiles/" + "YourEnteredName" '
                      'Example : enteredName.ini ')
    optionList.append("s <settingFile>")
    optionList.append("sFileName <settingFile>")
    parser.add_option('--sDirectoryPath',
                      help='The settings directory path. '
                      'Example : /home/yourname/.HamsiApps/HamsiManager ')
    optionList.append("sDirectoryPath <settingDirectory>")
    parser.add_option('-t', '--tableType',
                      help='Table Type Name. '
                      'Example : "0" for Folder Table '
                      'Example : "1" for File Table '
                      'Example : "2" for Music Table '
                      'Example : "3" for Subfolder Table '
                      'Example : "4" for Cover Table ')
    optionList.append("t <tableTypeNo>")
    optionList.append("tableType <tableTypeNo>")
    parser.add_option('-f', '--fileReNamerType',
                      help='File Renamer Type. '
                      'Example : "Personal Computer" '
                      'Example : "Web Server" '
                      'Example : "Removable Media" ')
    optionList.append("f <fileReNamerTypeNo>")
    optionList.append("fileReNamerType <fileReNamerTypeNo>")
    parser.add_option('--PyKDE4',
                      help='Are you want to activate PyKDE4. '
                      'Example : "1" or "True" for Yes '
                      'Example : "0" or "False" for No ')
    optionList.append("PyKDE4 <o>")
    qmgroup = OptionGroup(parser, "Quick Make Options",
                    "You can make quickly what are you want.")
    qmgroup.add_option('--qmw',
                      help='Are you want to show Quick Make Window. '
                      'Example : "1" or "True" for Yes '
                      'Example : "0" or "False" for No ')
    optionList.append("qmw <o>")
    qmgroup.add_option('--qm', help='Are you want to run Quick Make by some parametres?', 
                      action='store_const', const=True)
    optionList.append("qm")
    qmgroup.add_option('--pack',
                      help='The directory path. '
                      'Example : /home/yourname/someDirectory')
    optionList.append("pack <directory>")
    qmgroup.add_option('--hash',
                      help='The file path. '
                      'Example : /home/yourname/someFile')
    optionList.append("hash <file>")
    qmgroup.add_option('--checkIcon',
                      help='The directory path. '
                      'Example : /home/yourname/someDirectory')
    optionList.append("checkIcon <directory>")
    qmgroup.add_option('--clearEmptyDirectories',
                      help='The directory path. '
                      'Example : /home/yourname/someDirectory')
    optionList.append("clearEmptyDirectories <directory>")
    qmgroup.add_option('--clearUnneededs',
                      help='The directory path. '
                      'Example : /home/yourname/someDirectory')
    optionList.append("clearUnneededs <directory>")
    qmgroup.add_option('--clearIgnoreds',
                      help='The directory path. '
                      'Example : /home/yourname/someDirectory')
    optionList.append("clearIgnoreds <directory>")
    qmgroup.add_option('--emendFile',
                      help='The file path. '
                      'Example : /home/yourname/someFile')
    optionList.append("emendFile <file>")
    qmgroup.add_option('--emendDirectory',
                      help='The directory path. '
                      'Example : /home/yourname/someDirectory')
    optionList.append("emendDirectory <directory>")
    qmgroup.add_option('--emendDirectoryWithContents',
                      help='The directory path. '
                      'Example : /home/yourname/someDirectory')
    optionList.append("emendDirectoryWithContents <directory>")
    qmgroup.add_option('--copyPath',
                      help='The file/directory path. '
                      'Example : /home/yourname/somePath')
    optionList.append("copyPath <fileOrDirectory>")
    qmgroup.add_option('--fileTree',
                      help='The directory path. '
                      'Example : /home/yourname/someDirectory')
    optionList.append("fileTree <directory>")
    qmgroup.add_option('--removeOnlySubFiles',
                      help='The directory path. '
                      'Example : /home/yourname/someDirectory')
    optionList.append("removeOnlySubFiles <directory>")
    qmgroup.add_option('--clear',
                      help='The directory path. '
                      'Example : /home/yourname/someDirectory')
    optionList.append("clear <directory>")
    qmgroup.add_option('--textCorrector',
                      help='The file path. '
                      'Example : /home/yourname/someFile')
    optionList.append("textCorrector <file>")
    dgroup = OptionGroup(parser, "Dangerous Options",
                    "Caution: use these options at your own risk.  "
                    "It is believed that some of them bite.")
    dgroup.add_option('--checkAndGetOldAppNameInSystem', help='Are you want to check and get old app name in system?', 
                      action='store_const', const=True)
    optionList.append("checkAndGetOldAppNameInSystem")
    dgroup.add_option('--runAsRoot', help='Are you want to run as root?', 
                      action='store_const', const=True)
    optionList.append("runAsRoot")
    parser.add_option_group(qmgroup)
    parser.add_option_group(dgroup)
    parser.set_defaults(loggingLevel=logging.WARNING, 
                    checkAndGetOldAppNameInSystem=False, runAsRoot=False, qm=False)
    options, remainder = parser.parse_args()
    if len(remainder)==1:
        Universals.setMySetting("lastDirectory", remainder[0])
    if options.directory:
        Universals.setMySetting("lastDirectory", options.directory)
    if options.loggingLevel:
        Universals.loggingLevel = options.loggingLevel
    if options.sFileName:
        Universals.fileOfSettings = options.sFileName
    if options.sDirectoryPath:
        Universals.setPathOfSettingsDirectory(options.sDirectoryPath)
    if options.tableType:
        Universals.setMySetting("tableType", Universals.getThisTableType(options.tableType))
    if options.fileReNamerType:
        Universals.setMySetting("fileReNamerType", options.fileReNamerType)
    if options.PyKDE4:
        if options.PyKDE4.lower()=="false" or options.PyKDE4=="0":
            Universals.setMySetting("isActivePyKDE4", False)
        else:
            Universals.setMySetting("isActivePyKDE4", True)
    if options.qm:
        if options.qmw:
            if options.qmw.lower()=="false" or options.qmw=="0":
                Universals.setMySetting("isActivePyKDE4", False)
            else:
                Universals.setMySetting("isActivePyKDE4", True)
        if options.pack:
            QuickMakeParameters.append("pack")
            QuickMakeParameters.append(options.pack)
            isQuickMake = True
        elif options.hash:
            QuickMakeParameters.append("hash")
            QuickMakeParameters.append(options.hash)
            isQuickMake = True
        elif options.checkIcon:
            QuickMakeParameters.append("checkIcon")
            QuickMakeParameters.append(options.checkIcon)
            isQuickMake = True
        elif options.clearEmptyDirectories:
            QuickMakeParameters.append("clearEmptyDirectories")
            QuickMakeParameters.append(options.clearEmptyDirectories)
            isQuickMake = True
        elif options.clearUnneededs:
            QuickMakeParameters.append("clearUnneededs")
            QuickMakeParameters.append(options.clearUnneededs)
            isQuickMake = True
        elif options.clearIgnoreds:
            QuickMakeParameters.append("clearIgnoreds")
            QuickMakeParameters.append(options.clearIgnoreds)
            isQuickMake = True
        elif options.emendFile:
            QuickMakeParameters.append("emendFile")
            QuickMakeParameters.append(options.emendFile)
            isQuickMake = True
        elif options.emendDirectory:
            QuickMakeParameters.append("emendDirectory")
            QuickMakeParameters.append(options.emendDirectory)
            isQuickMake = True
        elif options.emendDirectoryWithContents:
            QuickMakeParameters.append("emendDirectoryWithContents")
            QuickMakeParameters.append(options.emendDirectoryWithContents)
            isQuickMake = True
        elif options.copyPath:
            QuickMakeParameters.append("copyPath")
            QuickMakeParameters.append(options.copyPath)
            isQuickMake = True
        elif options.fileTree:
            QuickMakeParameters.append("fileTree")
            QuickMakeParameters.append(options.fileTree)
            isQuickMake = True
        elif options.removeOnlySubFiles:
            QuickMakeParameters.append("removeOnlySubFiles")
            QuickMakeParameters.append(options.removeOnlySubFiles)
            isQuickMake = True
        elif options.clear:
            QuickMakeParameters.append("clear")
            QuickMakeParameters.append(options.clear)
            isQuickMake = True
        elif options.textCorrector:
            QuickMakeParameters.append("textCorrector")
            QuickMakeParameters.append(options.textCorrector)
            isQuickMake = True
    if options.runAsRoot:
        import Execute
        if Variables.isRunningAsRoot()==False:
            strArgvs = []
            for tempArg in sys.argv:
                if tempArg.find("-runAsRoot")==-1:
                    strArgvs.append(tempArg)
            if Execute.executeHamsiManagerAsRoot(strArgvs):
                isDontRun = True
    if options.checkAndGetOldAppNameInSystem:
        import OldAppName
        OldAppName.checkAndGetOldAppNameInSystem()
        isDontRun = True
    if isDontRun:
        return False
    return True

def checkAfterRunProccess():
    import Dialogs, Universals, Settings, UpdateControl
    from MyObjects import translate
    if str(Variables.defaultFileSystemEncoding) != str(Universals.MySettings["fileSystemEncoding"]):
        answer = Dialogs.ask(translate("HamsiManager", "Your System's \"File System Encoding\" Type Different"),
                    translate("HamsiManager", "Your system's \"File System Encoding\" type different from the settings you select. Are you sure you want to continue?If you are not sure press the \"No\"."), False, "Your System's \"File System Encoding\" Type Different")
        if answer==Dialogs.No: 
            import Options
            Options.Options(Universals.MainWindow, _focusTo="fileSystemEncoding")
    checkWindowMode()
    if Universals.getBoolValue("isMakeAutoDesign"):
        if Universals.isActivePyKDE4==True:
            Universals.MainWindow.Browser.setVisible(False)
            Universals.MainWindow.TreeBrowser.setVisible(False)
            Universals.MainWindow.FileManager.urlNavigator.setMinimumWidth(150)
            try:Universals.MainWindow.FileManager.dckwBrowserToolsFull.setVisible(False)
            except:Universals.MainWindow.FileManager.tbarBrowserToolsFull.setVisible(False)
        try:Universals.MainWindow.PlayerBar.setVisible(False)
        except:pass
    if Universals.isShowVerifySettings and Universals.changedDefaultValuesKeys==[]:
        answer = Dialogs.ask(translate("HamsiManager", "Added New Options And New Features"),
                    translate("HamsiManager", "New options and new features added to Hamsi Manager. Are you want to change or verify new options?"), False, "Added New Options And New Features")
        if answer==Dialogs.Yes: 
            import Options
            Options.Options(Universals.MainWindow)
    elif Universals.changedDefaultValuesKeys!=[] or Universals.newSettingsKeys!=[]:
        answer = Dialogs.ask(translate("HamsiManager", "Added New Options And New Features"),
                    translate("HamsiManager", "New options and new features added to Hamsi Manager. Changed default values of few settings. Are you want to change or verify new options?"), False, "Added New Options And New Features")
        if answer==Dialogs.Yes: 
            import Options
            newOrChangedKeys = Universals.newSettingsKeys + Universals.changedDefaultValuesKeys
            Options.Options(Universals.MainWindow, "Normal", None, newOrChangedKeys)
    elif Universals.getBoolValue("isShowReconfigureWizard"):
        import Execute
        Execute.executeReconfigure()
    elif UpdateControl.isMakeUpdateControl():
        UpdateControl.UpdateControl(Universals.MainWindow)
    
def checkWindowMode(_isCheck=False):
    import Dialogs, Universals, Settings 
    from MyObjects import translate
    if Universals.getBoolValue("isShowWindowModeSuggestion") or _isCheck:
        if Universals.windowMode == Variables.windowModeKeys[0]:
            screenSize = Variables.getScreenSize()
            if screenSize!=None:
                if screenSize.width()<1024:
                    Universals.windowMode = Variables.windowModeKeys[1]
        if Universals.windowMode == Variables.windowModeKeys[1]:
            answer = Dialogs.ask(translate("HamsiManager", "We Have A Suggestion"),
                    translate("HamsiManager", "Your screen size too small.Are you want to reorganize interface of Hamsi Manager for your screen size?"), False)
            if answer==Dialogs.Yes: 
                try:
                    Universals.MainWindow.TableToolsBar.setVisible(False)
                    Universals.MainWindow.ToolsBar.setVisible(False)
                    if Universals.MainWindow.MusicOptionsBar!=None:
                        Universals.MainWindow.MusicOptionsBar.setVisible(False)
                    if Universals.MainWindow.AmarokMusicOptionsBar!=None:
                        Universals.MainWindow.AmarokMusicOptionsBar.setVisible(False)
                    if Universals.MainWindow.SubDirectoryOptionsBar!=None:
                        Universals.MainWindow.SubDirectoryOptionsBar.setVisible(False)
                    if Universals.MainWindow.Browser!=None and Universals.MainWindow.Places!=None:
                        Universals.MainWindow.tabifyDockWidget(Universals.MainWindow.Browser, Universals.MainWindow.Places)
                    if Universals.MainWindow.Browser!=None and Universals.MainWindow.TreeBrowser!=None:
                        Universals.MainWindow.tabifyDockWidget(Universals.MainWindow.Browser, Universals.MainWindow.TreeBrowser)
                    if Universals.MainWindow.Browser!=None and Universals.MainWindow.DirOperator!=None:
                        Universals.MainWindow.tabifyDockWidget(Universals.MainWindow.Browser, Universals.MainWindow.DirOperator)
                    geometries = Universals.getListFromStrint(Universals.MySettings["MainWindowGeometries"])
                    Universals.MainWindow.setGeometry(int(geometries[0]),int(geometries[1]), 700, 500)
                except:pass
            Universals.setMySetting("isShowWindowModeSuggestion", False)
     
def checkAfterCloseProccess():
    import Records
    Records.saveAllRecords()
    Records.checkSize()
    
def checkMyModules(_HamsiManagerApp):
    try:
        import SpecialTools
        import Tables
        import FileManager
        import Bars
        return True
    except ImportError as error:
        errorForm = Variables.MQtGui.QWidget()
        errorForm.vblMain = Variables.MQtGui.QVBoxLayout(errorForm)
        if str(error)[16:].find(" ")==-1:
            title = str(Variables.MQtGui.QApplication.translate("ReportBug", "Missing Module"))
            startNumber=16
            details = str(Variables.MQtGui.QApplication.translate("ReportBug", "Application will not work without the module \"%s\"."))
        else:
            title = str(Variables.MQtGui.QApplication.translate("ReportBug", "Error In Module"))
            startNumber=19
            details = str(Variables.MQtGui.QApplication.translate("ReportBug", "\"%s\" is not in this module.Please download and install Hamsi Manager again."))
        lblDetails = Variables.MQtGui.QLabel(Universals.trForM("<b>"+title+":</b><br>"+ (details % (str(error)[startNumber:]))))
        pbtnOk = Variables.MQtGui.QPushButton(Variables.MQtGui.QApplication.translate("ReportBug", "OK"))
        errorForm.connect(pbtnOk,Variables.MQtCore.SIGNAL("clicked()"), _HamsiManagerApp.quit)
        hbox0 = Variables.MQtGui.QHBoxLayout()
        hbox0.addStretch(2)
        hbox0.addWidget(pbtnOk,1)
        errorForm.vblMain.addWidget(lblDetails)
        errorForm.vblMain.addLayout(hbox0)
        errorForm.setWindowTitle(Variables.MQtGui.QApplication.translate("ReportBug", "Critical Error!"))
        errorForm.show()
        sys.exit(_HamsiManagerApp.exec_())
    return False
    
def checkQt4Exist():
    if Variables.isQt4Exist:
        return True
    else:
        try:
            import qt
            HamsiManagerApp=qt.QApplication(sys.argv)
            panel = qt.QWidget()
            panel.vblMain = qt.QVBoxLayout(panel)
            lblInfo = qt.QLabel(Universals.trDecode("<br><b>PyQt4 or PySide is not installed:</b><br>You have to have \"PyQt4\" or \"PySide\" installed on your system to run Hamsi Manager.", "utf-8"),panel)
            pbtnClose = qt.QPushButton("OK",panel)
            panel.connect(pbtnClose,SIGNAL("clicked()"),HamsiManagerApp.quit)
            hbox0 = qt.QHBoxLayout()
            hbox0.addStretch(2)
            hbox0.addWidget(pbtnClose,1)
            vbox0 = qt.QVBoxLayout()
            vbox0.addWidget(lblInfo)
            vbox0.addLayout(hbox0)
            hbox1 = qt.QHBoxLayout()
            hbox1.addStretch(20)
            hbox1.addLayout(vbox0,500)
            hbox1.addStretch(5)
            panel.vblMain.addLayout(hbox1)
            panel.setCaption("Critical Error!")
            panel.show()
            panel.setMinimumWidth(400)
            HamsiManagerApp.enter_loop()
        except:
            try:
                import gtk
                def destroy( widget, data=None):
                    gtk.main_quit()
                window = gtk.Window(gtk.WINDOW_TOPLEVEL)
                window.connect("destroy", destroy)
                window.set_title("Critical Error!")
                button = gtk.Button("OK")
                label = gtk.Label("PyQt4 is not installed.")
                label2 = gtk.Label("You have to have \"PyQt4\" or \"PySide\" installed on your system to run Hamsi Manager.")
                label2.set_line_wrap(True)
                button.connect("clicked", gtk.main_quit, None)
                vbox = gtk.VBox(False,5)
                hbox = gtk.HBox(window)
                window.add(hbox)
                hbox.pack_start(vbox, False, False, 0)
                window.set_border_width(5)
                hbox0 = gtk.HBox(False)
                hbox0.pack_start(label, 0, 0, 0)
                hbox1 = gtk.HBox(False)
                label3 = gtk.Label("")
                hbox1.pack_start(label3, 0, 0, 0)
                hbox1.pack_start(button, 0, 0, 0)
                vbox.pack_start(hbox0, False, False, 0)
                vbox.pack_start(label2, False, False, 0)
                vbox.pack_start(hbox1, False, False, 0)
                layout = gtk.Layout(None, None)
                button.set_size_request(120,25)
                label2.set_size_request(350,35)
                label3.set_size_request(230,25)
                window.show_all()
                gtk.main()
            except:
                try:
                    import Tkinter
                    MainWindow = Tkinter.Tk()
                    MainWindow.geometry("350x100")
                    title = MainWindow.title("Critical Error!")
                    lbl1 = Tkinter.Label(text="PyQt4 is not installed.")
                    lbl1.pack()
                    lbl2 = Tkinter.Label(text="You have to have \"PyQt4\" or \"PySide\" installed")
                    lbl2.pack()
                    lbl3 = Tkinter.Label(text="on your system to run HamsiManager.")
                    lbl3.pack()
                    btnClose = Tkinter.Button(text="OK", command = MainWindow.quit)
                    btnClose.pack(side = Tkinter.RIGHT)
                    Tkinter.mainloop()
                except:
                    print ("Critical Error!")
                    print ("You have to have \"PyQt4\" or \"PySide\" installed on your system to run Hamsi Manager.")
        return False    
        
        
        
    



## This file is part of HamsiManager.
## 
## Copyright (c) 2010 Murat Demir <mopened@gmail.com>      
##
## Hamsi Manager is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
## 
## Hamsi Manager is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
## 
## You should have received a copy of the GNU General Public License
## along with HamsiManager; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA


def checkOldAppNameAndSettings():
    import Variables, InputOutputs, Universals
    return InputOutputs.isDir(Variables.userDirectoryPath + "/.OrganizasyonizM")
    
def checkOldAppNameInSystem():
    import InputOutputs
    return InputOutputs.isFile("/usr/bin/OrganizasyonizM")
    
def getSettingsFromOldNameAndSettings():
    import Variables, InputOutputs, Universals
    if InputOutputs.isDir(Variables.userDirectoryPath + "/.OrganizasyonizM"):
        if InputOutputs.isFile(Variables.userDirectoryPath + "/.OrganizasyonizM/universalSettings.ini"):
            from MyObjects import MSettings, trForM
            oldSettins = MSettings(trForM(Variables.userDirectoryPath+"/.OrganizasyonizM/universalSettings.ini") ,MSettings.IniFormat)
            newSettings = MSettings(trForM(Variables.userDirectoryPath+"/.HamsiApps/universalSettings.ini") ,MSettings.IniFormat)
            for oldKey in oldSettins.allKeys():
                newKey = str(oldKey).replace("OrganizasyonizM", "HamsiManager")
                newSettings.setValue(newKey, oldSettins.value(oldKey))
        if InputOutputs.isFile(Variables.userDirectoryPath + "/.OrganizasyonizM/mySettings.ini"):
            from MyObjects import MSettings, trForM
            oldSettins = MSettings(trForM(Variables.userDirectoryPath+"/.OrganizasyonizM/mySettings.ini") ,MSettings.IniFormat)
            newSettings = MSettings(trForM(Variables.userDirectoryPath+"/.HamsiApps/HamsiManager/mySettings.ini") ,MSettings.IniFormat)
            for oldKey in oldSettins.allKeys():
                newKey = str(oldKey).replace("OrganizasyonizM", "HamsiManager")
                newSettings.setValue(newKey, oldSettins.value(oldKey))
        if InputOutputs.isFile(Variables.userDirectoryPath + "/.OrganizasyonizM/bookmarks.sqlite"):
            InputOutputs.moveFileOrDir(Variables.userDirectoryPath + "/.OrganizasyonizM/bookmarks.sqlite", 
                                       Variables.userDirectoryPath + "/.HamsiApps/HamsiManager/bookmarks.sqlite")
        if InputOutputs.isFile(Variables.userDirectoryPath + "/.OrganizasyonizM/codesOfUser.py"):
            InputOutputs.moveFileOrDir(Variables.userDirectoryPath + "/.OrganizasyonizM/codesOfUser.py", 
                                       Variables.userDirectoryPath + "/.HamsiApps/HamsiManager/codesOfUser.py")
        if InputOutputs.isFile(Variables.userDirectoryPath + "/.OrganizasyonizM/LastState"):
            InputOutputs.moveFileOrDir(Variables.userDirectoryPath + "/.OrganizasyonizM/LastState", 
                                       Variables.userDirectoryPath + "/.HamsiApps/HamsiManager/LastState")
        if InputOutputs.isFile(Variables.userDirectoryPath + "/.OrganizasyonizM/logs.txt"):
            InputOutputs.moveFileOrDir(Variables.userDirectoryPath + "/.OrganizasyonizM/logs.txt", 
                                       Variables.userDirectoryPath + "/.HamsiApps/HamsiManager/logs.txt")
        if InputOutputs.isFile(Variables.userDirectoryPath + "/.OrganizasyonizM/searchAndReplaceTable.sqlite"):
            InputOutputs.moveFileOrDir(Variables.userDirectoryPath + "/.OrganizasyonizM/searchAndReplaceTable.sqlite", 
                                       Variables.userDirectoryPath + "/.HamsiApps/HamsiManager/searchAndReplaceTable.sqlite")
        if InputOutputs.isDir(Variables.userDirectoryPath + "/.OrganizasyonizM/SettingFiles"):
            isMakeThis = True
            if InputOutputs.isDir(Variables.userDirectoryPath + "/.HamsiApps/HamsiManager/SettingFiles"):
                if InputOutputs.isDirEmpty(Variables.userDirectoryPath + "/.HamsiApps/HamsiManager/SettingFiles"):
                    InputOutputs.removeDir(Variables.userDirectoryPath + "/.HamsiApps/HamsiManager/SettingFiles")
                else:
                    isMakeThis = False
            if isMakeThis:
                InputOutputs.moveFileOrDir(Variables.userDirectoryPath + "/.OrganizasyonizM/SettingFiles", 
                                       Variables.userDirectoryPath + "/.HamsiApps/HamsiManager/SettingFiles")
        if InputOutputs.isDir(Variables.userDirectoryPath + "/.OrganizasyonizM/BackUps"):
            isMakeThis = True
            if InputOutputs.isDir(Variables.userDirectoryPath + "/.HamsiApps/HamsiManager/BackUps"):
                if InputOutputs.isDirEmpty(Variables.userDirectoryPath + "/.HamsiApps/HamsiManager/BackUps"):
                    InputOutputs.removeDir(Variables.userDirectoryPath + "/.HamsiApps/HamsiManager/BackUps")
                else:
                    isMakeThis = False
            if isMakeThis:
                InputOutputs.moveFileOrDir(Variables.userDirectoryPath + "/.OrganizasyonizM/BackUps", 
                                       Variables.userDirectoryPath + "/.HamsiApps/HamsiManager/BackUps")
        if Variables.isAvailableKDE4():
            if InputOutputs.isFile(Variables.userDirectoryPath + "/.kde4/share/config/OrganizasyonizMrc"):
                InputOutputs.moveFileOrDir(Variables.userDirectoryPath + "/.kde4/share/config/OrganizasyonizMrc", 
                                           Variables.getKDE4HomePath() + "/share/config/HamsiManagerrc")
        for langCode in Variables.getInstalledLanguagesCodes():
            if InputOutputs.isFile(Variables.userDirectoryPath + "/.kde4/share/locale/" + langCode + "/LC_MESSAGES/OrganizasyonizM.mo"):
                import MyConfigure
                MyConfigure.installKDE4Language(langCode)
        Universals.fillMySettings(True)
        Universals.saveSettings()
    
def checkAndGetPlugins():
    import Variables, InputOutputs, Universals
    for plugin in Variables.getMyPluginsNames():
        isInstalled = False
        pluginModule = __import__("MyPlugins." + plugin, globals(), locals(), ["pluginFiles", "pluginDirectory", "setupDirectory"], -1)
        for pluginFile in pluginModule.pluginFiles:
            if InputOutputs.isFile((pluginModule.setupDirectory + "/" + pluginFile).replace("HamsiManager", "OrganizasyonizM")):
                isInstalled = True
                break
        if pluginModule.pluginDirectory!="":
            if InputOutputs.isDir((pluginModule.setupDirectory + "/" + pluginModule.pluginDirectory).replace("HamsiManager", "OrganizasyonizM")):
                isInstalled = True
        if isInstalled:
            from MyPlugins import installPlugin
            installPlugin(plugin, True)
        
        
def clearOldAppNameAndSettings():
    import Variables, InputOutputs, Universals, Dialogs, Organizer
    from MyObjects import translate
    #Clear language file
    for langCode in Variables.getInstalledLanguagesCodes():
        if InputOutputs.isFile(Variables.userDirectoryPath + "/.kde4/share/locale/" + langCode + "/LC_MESSAGES/OrganizasyonizM.mo"):
            InputOutputs.removeFile(Variables.userDirectoryPath + "/.kde4/share/locale/" + langCode + "/LC_MESSAGES/OrganizasyonizM.mo")
    #Clear config file
    if InputOutputs.isFile(Variables.userDirectoryPath + "/.kde4/share/config/OrganizasyonizMrc"):
        InputOutputs.removeFile(Variables.userDirectoryPath + "/.kde4/share/config/OrganizasyonizMrc")
    #Clear My Plugins
    for plugin in Variables.getMyPluginsNames():
        pluginModule = __import__("MyPlugins." + plugin, globals(), locals(), ["pluginFiles", "pluginDirectory", "setupDirectory"], -1)
        for pluginFile in pluginModule.pluginFiles:
            pluginFilePath = (pluginModule.setupDirectory + "/" + pluginFile).replace("HamsiManager", "OrganizasyonizM")
            if InputOutputs.isFile(pluginFilePath):
                InputOutputs.removeFile(pluginFilePath)
        if pluginModule.pluginDirectory!="":
            pluginDirectoryPath = (pluginModule.setupDirectory + "/" + pluginModule.pluginDirectory).replace("HamsiManager", "OrganizasyonizM")
            if InputOutputs.isDir(pluginDirectoryPath):
                InputOutputs.removeFileOrDir(pluginDirectoryPath, True)
    #Clear Setting Directory
    if InputOutputs.isDir(Variables.userDirectoryPath + "/.OrganizasyonizM"):
        isRemoveOldSettingDirectory = False
        if InputOutputs.isDirEmpty(Variables.userDirectoryPath + "/.OrganizasyonizM"):
            isRemoveOldSettingDirectory = True
        else:
            answer = Dialogs.ask(translate("HamsiManager", "The Old Version Was Detected"),
                    str(translate("HamsiManager", "OrganizasyonizM setting directory was detected.Are you want to delete \"%s\"?<br>Note:This directory will not be used anymore.You can delete this directory.")) % Organizer.getLink(Variables.userDirectoryPath + "/.OrganizasyonizM"), False, "OrganizasyonizM Setting Directory Was Detected")
            if answer==Dialogs.Yes:
                isRemoveOldSettingDirectory = True
        if isRemoveOldSettingDirectory:
            InputOutputs.removeFileOrDir(Variables.userDirectoryPath + "/.OrganizasyonizM", True)

def checkAndGetOldAppNameInSystem():
    import Variables, InputOutputs, Dialogs, Execute, Organizer, Universals
    from MyObjects import translate
    #Clear OrganizasyonizM in system(/usr/bin/OrganizasyonizM) by root
    if Variables.isRunningAsRoot():
        if InputOutputs.isFile("/usr/bin/OrganizasyonizM"):
            InputOutputs.removeFile("/usr/bin/OrganizasyonizM")
        if InputOutputs.isFile("/usr/bin/hamsimanager")==False:
            InputOutputs.createSymLink(Variables.executableHamsiManagerPath, "/usr/bin/hamsimanager")
    else:
        answer = Dialogs.ask(translate("HamsiManager", "The Old Version Was Detected"),
                    str(translate("HamsiManager", "Executable OrganizasyonizM file was detected in your system.Are you want to delete \"%s\" and creat new Executable Hamsi Manager(\"%s\")?")) % (Organizer.getLink("/usr/bin/OrganizasyonizM") , Organizer.getLink("/usr/bin/hamsimanager")), False, "Executable OrganizasyonizM Was Detected")
        if answer==Dialogs.Yes:
            Execute.executeHamsiManagerAsRoot(["--checkAndGetOldAppNameInSystem"])
    



## This file is part of HamsiManager.
## 
## Copyright (c) 2010 Murat Demir <mopened@gmail.com>      
##
## Hamsi Manager is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
## 
## Hamsi Manager is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
## 
## You should have received a copy of the GNU General Public License
## along with HamsiManager; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

from urllib import unquote, quote
import Amarok
import Databases

class Commands:
    global getDirectoriesAndValues, changePath, getDevices, changeTag, getOrInsertArtist, getOrInsertAlbum, getOrInsertYear, getOrInsertGenre, getAllMusicFileValues, getMusicFileValues, getAllMusicFileValuesWithNames
    
    def getDirectoriesAndValues():
        db = Amarok.checkAndGetDB()
        db.query("""
SELECT DISTINCT (
    REPLACE(
        CONCAT(
            CASE WHEN `devices`.`lastmountpoint` IS NOT NULL
                THEN `devices`.`lastmountpoint`
            ELSE 
                ''
            END, 
            SUBSTRING( `urls`.`rpath` , 2 )
        ),
        CONCAT("/", 
            SUBSTRING_INDEX(
                CONCAT(
                    CASE WHEN `devices`.`lastmountpoint` IS NOT NULL
                        THEN `devices`.`lastmountpoint`
                    ELSE 
                        ''
                    END, 
                    SUBSTRING( `urls`.`rpath` , 2 )
                ), 
                "/" , -1)
        )
    , "")
) AS 'dirPath', 
`images`.`path`, 
`artists`.`name`, 
`albums`.`name`, 
`years`.`name`, 
`genres`.`name`
FROM `tracks`
LEFT JOIN `urls` ON `urls`.`id` = `tracks`.`url`
LEFT JOIN `devices` ON `devices`.`id` = `urls`.`deviceid`
LEFT JOIN `artists` ON `artists`.`id` = `tracks`.`artist`
LEFT JOIN `albums` ON `albums`.`id` = `tracks`.`album`
LEFT JOIN `years` ON `years`.`id` = `tracks`.`year`
LEFT JOIN `genres` ON `genres`.`id` = `tracks`.`genre`
LEFT JOIN `images` ON `images`.`id` = `albums`.`image`
WHERE `images`.`path` IS NOT NULL and `images`.`id` NOT IN (SELECT `id` FROM `images` WHERE path not like '/%') 
order by 'dirPath'
""")
        r = db.store_result()
        directoriesValues = {}
        rows = r.fetch_row(0)
        for row in rows:
            if row[0] not in directoriesValues:
                directoriesValues[row[0]] = {"coverPath" : [], "artist" : [], "album" : [], "year" : [], "genre" : []}
            directoriesValues[row[0]]["coverPath"].append(row[1])
            directoriesValues[row[0]]["artist"].append(row[2])
            directoriesValues[row[0]]["album"].append(row[3])
            directoriesValues[row[0]]["year"].append(row[4])
            directoriesValues[row[0]]["genre"].append(row[5])
        return directoriesValues
    
    def getAllMusicFileValues():
        db = Amarok.checkAndGetDB()
        db.query("""
SELECT `tracks`.`id`, (
    REPLACE(
        CONCAT(
            CASE WHEN `devices`.`lastmountpoint` IS NOT NULL
                THEN `devices`.`lastmountpoint`
            ELSE 
                ''
            END, 
            SUBSTRING( `urls`.`rpath` , 2 )
        ),
        CONCAT("/", 
                CONCAT(
                    CASE WHEN `devices`.`lastmountpoint` IS NOT NULL
                        THEN `devices`.`lastmountpoint`
                    ELSE 
                        ''
                    END, 
                    SUBSTRING( `urls`.`rpath` , 2 )
                )
        )
    , "")
) AS 'filePath', 
`tracks`.`title`, 
`tracks`.`artist`, 
`tracks`.`album`, 
`tracks`.`year`, 
`tracks`.`genre`, 
`tracks`.`tracknumber`, 
`tracks`.`comment`
FROM `tracks`
LEFT JOIN `urls` ON `urls`.`id` = `tracks`.`url`
LEFT JOIN `devices` ON `devices`.`id` = `urls`.`deviceid`
""")
        r = db.store_result()
        musicFileValues = []
        rows = r.fetch_row(0)
        for row in rows:
            musicFileValues.append({})
            musicFileValues[-1]["id"] = row[0]
            musicFileValues[-1]["filePath"] = row[1]
            musicFileValues[-1]["title"] = row[2]
            musicFileValues[-1]["artistId"] = row[3]
            musicFileValues[-1]["albumId"] = row[4]
            musicFileValues[-1]["yearId"] = row[5]
            musicFileValues[-1]["genreId"] = row[6]
            musicFileValues[-1]["tracknumber"] = row[7]
            musicFileValues[-1]["comment"] = row[8]
        return musicFileValues
        
    def getAllMusicFileValuesWithNames():
        db = Amarok.checkAndGetDB()
        db.query("""
SELECT `valueTable`.* , `lyrics`.`lyrics` FROM (
    SELECT `tracks`.`id`, CONVERT(
        REPLACE(
            CONCAT(
                CASE WHEN `devices`.`lastmountpoint` IS NOT NULL
                    THEN `devices`.`lastmountpoint`
                ELSE 
                    ''
                END, 
                SUBSTRING( `urls`.`rpath` , 2 )
            ),
            CONCAT("/", 
                    CONCAT(
                        CASE WHEN `devices`.`lastmountpoint` IS NOT NULL
                            THEN `devices`.`lastmountpoint`
                        ELSE 
                            ''
                        END, 
                        SUBSTRING( `urls`.`rpath` , 2 )
                    )
            )
        , "")
    , char(1000)) AS 'filePath', 
    `tracks`.`title`, 
    `tracks`.`artist`, 
    `tracks`.`album`, 
    `tracks`.`year`, 
    `tracks`.`genre`, 
    `tracks`.`tracknumber`, 
    `tracks`.`comment`,
    `artists`.`name` AS 'artistname',
    `albums`.`name` AS 'albumname',
    `albumartists`.`name` AS 'albumartistname',
    `years`.`name` AS 'yearname',
    `genres`.`name` AS 'genrename',
    `images`.`path`
    FROM `tracks`
    LEFT JOIN `urls` ON `urls`.`id` = `tracks`.`url`
    LEFT JOIN `devices` ON `devices`.`id` = `urls`.`deviceid`
    LEFT JOIN `artists` ON `artists`.`id` = `tracks`.`artist`
    LEFT JOIN `albums` ON `albums`.`id` = `tracks`.`album`
    LEFT JOIN `artists` `albumartists` ON `albumartists`.`id` = `albums`.`artist`
    LEFT JOIN `years` ON `years`.`id` = `tracks`.`year`
    LEFT JOIN `genres` ON `genres`.`id` = `tracks`.`genre`
    LEFT JOIN `images` ON `images`.`id` = `albums`.`image`
) as `valueTable`
LEFT JOIN `lyrics` ON `lyrics`.`url` = CONCAT('.' , `valueTable`.`filePath`)
""")
        r = db.store_result()
        musicFileValues = []
        rows = r.fetch_row(0)
        for row in rows:
            musicFileValues.append({})
            musicFileValues[-1]["id"] = row[0]
            musicFileValues[-1]["filePath"] = row[1]
            musicFileValues[-1]["title"] = row[2]
            musicFileValues[-1]["artistId"] = row[3]
            musicFileValues[-1]["albumId"] = row[4]
            musicFileValues[-1]["yearId"] = row[5]
            musicFileValues[-1]["genreId"] = row[6]
            musicFileValues[-1]["tracknumber"] = row[7]
            musicFileValues[-1]["comment"] = row[8]
            musicFileValues[-1]["artist"] = row[9]
            musicFileValues[-1]["album"] = row[10]
            musicFileValues[-1]["albumartist"] = row[11]
            musicFileValues[-1]["year"] = row[12]
            musicFileValues[-1]["genre"] = row[13]
            musicFileValues[-1]["imagePath"] = row[14]
            musicFileValues[-1]["lyrics"] = row[15]
        return musicFileValues
        
    def getMusicFileValues(_path):
        db = Amarok.checkAndGetDB()
        db.query("""
SELECT * FROM (
    SELECT `tracks`.`id`, CONVERT((
        REPLACE(
            CONCAT(
                CASE WHEN `devices`.`lastmountpoint` IS NOT NULL
                    THEN `devices`.`lastmountpoint`
                ELSE 
                    ''
                END, 
                SUBSTRING( `urls`.`rpath` , 2 )
            ),
            CONCAT("/", 
                    CONCAT(
                        CASE WHEN `devices`.`lastmountpoint` IS NOT NULL
                            THEN `devices`.`lastmountpoint`
                        ELSE 
                            ''
                        END, 
                        SUBSTRING( `urls`.`rpath` , 2 )
                    )
            )
        , "")
    ), char(1000)) AS 'filePath', 
    `tracks`.`title`, 
    `tracks`.`artist`, 
    `tracks`.`album`, 
    `tracks`.`year`, 
    `tracks`.`genre`, 
    `tracks`.`tracknumber`, 
    `tracks`.`comment`
    FROM `tracks`
    LEFT JOIN `urls` ON `urls`.`id` = `tracks`.`url`
    LEFT JOIN `devices` ON `devices`.`id` = `urls`.`deviceid`
) as `valueTable` WHERE `valueTable`.`filePath` = '%s'
""" % _path)
        r = db.store_result()
        musicFileValues = {}
        rows = r.fetch_row(0)
        if len(rows)==0:
            return None
        row = rows[0]
        musicFileValues["id"] = row[0]
        musicFileValues["filePath"] = row[1]
        musicFileValues["title"] = row[2]
        musicFileValues["artistId"] = row[3]
        musicFileValues["albumId"] = row[4]
        musicFileValues["yearId"] = row[5]
        musicFileValues["genreId"] = row[6]
        musicFileValues["tracknumber"] = row[7]
        musicFileValues["comment"] = row[8]
        return musicFileValues
        
    def getDevices():
        db = Amarok.checkAndGetDB()
        db.query("SELECT id,lastmountpoint FROM devices")
        r = db.store_result()
        return r.fetch_row(0)
        
    def getOrInsertArtist(_artist):
        db = Amarok.checkAndGetDB()
        db.query(Databases.getAmendedSQLSelectOrInsertAndSelectQueries("artists", "id", {"name" : "'" + _artist + "'"}))
        r = db.store_result()
        return r.fetch_row(0)[0][0]
        
    def getOrInsertAlbum(_album, _artistId):
        db = Amarok.checkAndGetDB()
        db.query(Databases.getAmendedSQLSelectOrInsertAndSelectQueries("albums", "id", {"name" : "'" + _album + "'", "artist" : "'" + _artistId + "'"}))
        r = db.store_result()
        return r.fetch_row(0)[0][0]
        
    def getOrInsertYear(_year):
        db = Amarok.checkAndGetDB()
        db.query(Databases.getAmendedSQLSelectOrInsertAndSelectQueries("years", "id", {"name" : "'" + _year + "'"}))
        r = db.store_result()
        return r.fetch_row(0)[0][0]
        
    def getOrInsertGenre(_genre):
        db = Amarok.checkAndGetDB()
        db.query(Databases.getAmendedSQLSelectOrInsertAndSelectQueries("genres", "id", {"name" : "'" + _genre + "'"}))
        r = db.store_result()
        return r.fetch_row(0)[0][0]
    
    def changePath(_oldPath, _newPath):
        _oldPath, _newPath = str(_oldPath), str(_newPath)
        _oldPathUrl, _newPathUrl = quote(_oldPath), quote(_newPath)
        withOutDevicePoints, withOutDevice = [], []
        for devicePoint in getDevices():
            if devicePoint[1] + "/" == _oldPath[:len(devicePoint[1])+1]:
                if devicePoint[1] + "/" == _newPath[:len(devicePoint[1])+1]:
                    withOutDevicePoints.append({"id":devicePoint[0], 
                                                "oldPath":  _oldPath[len(devicePoint[1]):], 
                                                "newPath": _newPath[len(devicePoint[1]):]
                                                })
                else:
                    withOutDevice.append({"id": devicePoint[0], 
                                        "oldPath":  _oldPath[len(devicePoint[1]):], 
                                        "newPath": _newPath
                                                })
        db = Amarok.checkAndGetDB()
        db.query("UPDATE directories SET dir=REPLACE(dir, '.%s/', '.%s/')" % (_oldPath, _newPath))
        db.query("UPDATE urls SET rpath='.%s' WHERE rpath='.%s'" % (_newPath, _oldPath))
        for withOutDevice in withOutDevice:
            db.query("UPDATE directories SET dir='.%s/', deviceid = -1 WHERE deviceid = %s and dir = '.%s/' " % (withOutDevice["newPath"], withOutDevice["id"], withOutDevice["oldPath"]))
            db.query("UPDATE urls SET rpath='.%s/', deviceid = -1 WHERE deviceid = %s and rpath = '.%s/' " % (withOutDevice["newPath"], withOutDevice["id"], withOutDevice["oldPath"]))
        for withOutDevicePoint in withOutDevicePoints:
            db.query("UPDATE directories SET dir='.%s/' WHERE deviceid = %s and dir = '.%s/'" % (withOutDevicePoint["newPath"], withOutDevicePoint["id"], withOutDevicePoint["oldPath"]))
            db.query("UPDATE urls SET rpath='.%s/' WHERE deviceid = %s and rpath = '.%s/'" % (withOutDevicePoint["newPath"], withOutDevicePoint["id"], withOutDevicePoint["oldPath"]))
        db.query("UPDATE images SET path='%s' WHERE path='%s'" % (_newPath, _oldPath))
        db.query("UPDATE lyrics SET url='.%s' WHERE url='.%s'" % (_newPath, _oldPath))
        db.query("UPDATE statistics_permanent SET url='file://%s' WHERE url='file://%s'" % (_newPathUrl, _oldPathUrl))
        db.commit()
        return True
        
    def changeTag(_values):
        if len(_values)>1:
            db = Amarok.checkAndGetDB()
            path = _values["path"]
            oldValues = getMusicFileValues(path)
            if oldValues is None:
                return False
            trackId, artistId, albumId, yearId, genreId = oldValues["id"], oldValues["artistId"], oldValues["albumId"], oldValues["yearId"], oldValues["genreId"]
            title = oldValues["title"]
            trackNum = oldValues["tracknumber"]
            firstComment = oldValues["comment"]
            if "artist" in _values:
                artistId = getOrInsertArtist(_values["artist"])
            if "title" in _values:
                title = _values["title"]
            if "album" in _values:
                albumId = getOrInsertAlbum(_values["album"], artistId)
            if "trackNum" in _values:
                trackNum = _values["trackNum"]
            if "year" in _values:
                yearId = getOrInsertYear(_values["year"])
            if "genre" in _values:
                genreId = getOrInsertGenre(_values["genre"])
            if "firstComment" in _values:
                firstComment = _values["firstComment"]
            if "firstLyrics" in _values:
                db.query("UPDATE lyrics SET lyrics='%s' WHERE url='.%s'" % (_values["firstLyrics"], path))
            db.query("UPDATE tracks SET artist=%s, title='%s', album=%s, tracknumber=%s, year=%s, genre=%s, comment='%s' WHERE id=%s" % (artistId, title, albumId, trackNum, yearId, genreId, firstComment, trackId))
            db.commit()
        return True
        
        
        
        
            




## This file is part of HamsiManager.
## 
## Copyright (c) 2010 Murat Demir <mopened@gmail.com>      
##
## Hamsi Manager is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
## 
## Hamsi Manager is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
## 
## You should have received a copy of the GNU General Public License
## along with HamsiManager; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA


from MyObjects import *
import sys
import Settings
import Dialogs
import Universals
import InputOutputs

class RunCommand(MDialog):
    global checkRunCommand, codesOfUser, reFillCodesOfUser
    def __init__(self, _parent):
        MDialog.__init__(self, _parent)
        from PyQt4.Qsci import QsciScintilla, QsciLexerPython, QsciAPIs
        if Universals.isActivePyKDE4==True:
            self.setButtons(MDialog.NoDefault)
        self.sciCommand = QsciScintilla()
        self.sciCommand.setUtf8(True)
        self.sciCommand.setText(trForUI(codesOfUser()))
        self.sciCommand.setAutoIndent(True)
        self.sciCommand.setAutoCompletionThreshold(2)
        self.sciCommand.setAutoCompletionSource(QsciScintilla.AcsDocument)
        self.sciCommand.setLexer(QsciLexerPython(self))
        pbtnRunCommandAndClose = MPushButton(translate("RunCommand", "Run And Close"))
        pbtnRunCommand = MPushButton(translate("RunCommand", "Run"))
        pbtnClose = MPushButton(translate("RunCommand", "Close"))
        pbtnClear = MPushButton(translate("RunCommand", "Clear"))
        self.connect(pbtnRunCommandAndClose,SIGNAL("clicked()"),self.runCommandAndClose)
        self.connect(pbtnRunCommand,SIGNAL("clicked()"),self.runCommand)
        self.connect(pbtnClose,SIGNAL("clicked()"),self.close)
        self.connect(pbtnClear,SIGNAL("clicked()"),self.clear)
        pnlMain = MWidget(self)
        vblMain = MVBoxLayout(pnlMain)
        hbox = MHBoxLayout()
        hbox.addStretch(1)
        hbox.addWidget(pbtnClear,1)
        hbox.addWidget(pbtnRunCommand,1)
        hbox.addWidget(pbtnRunCommandAndClose,1)
        hbox.addWidget(pbtnClose,1)
        vblMain.addWidget(self.sciCommand)
        vblMain.addLayout(hbox)
        if Universals.isActivePyKDE4==True:
            self.setMainWidget(pnlMain)
        else:
            self.setLayout(vblMain)
        self.setWindowTitle(translate("RunCommand", "Run Command"))
        self.setWindowIcon(MIcon("Images:runCommand.png"))
        self.setMinimumWidth(500)
        self.setMinimumHeight(450)
        self.show()

    def closeEvent(self, _event):
        if self.saveCommand()==False:
            _event.ignore() 
    
    def checkRunCommand(_isAlertIfNotAvailable=True):
        try:
            from PyQt4.Qsci import QsciScintilla
            return True
        except:
            if _isAlertIfNotAvailable:
                Dialogs.showError(translate("MenuBar", "Qsci Is Not Installed"), 
                    translate("MenuBar", "Qsci is not installed on your systems.<br>Please install Qsci on your system and try again."))
            return False
    
    def codesOfUser(_codes=""):
        if _codes=="":
            if InputOutputs.IA.isFile(Universals.pathOfSettingsDirectory + "/codesOfUser.py")==False:
                reFillCodesOfUser()
            return InputOutputs.IA.readFromFile(Universals.pathOfSettingsDirectory + "/codesOfUser.py")
        else:
            InputOutputs.IA.writeToFile(Universals.pathOfSettingsDirectory + "/codesOfUser.py", _codes)

    def reFillCodesOfUser():
        codesOfUser("#!/usr/bin/env python\n" +
                            "# -*- codding: utf-8 -*-\n"+
                            "\n"+
                            "#You can type and execute the commands you wish to run here.\n"+
                            "#You can get detailed information from our official website.\n"+
                            "import Dialogs\nDialogs.show(\"This is an example\",\"You can develop the examples as you wish.\")"+
                            "\n\n\n\n\n\n\n\n\n")
        
    def runCommandAndClose(self):
        if self.runCommand():
            self.close()
        
    def runCommand(self):
        try:
            exec (str(self.sciCommand.text()))
            return True
        except Exception as error:
            import traceback
            cla, error, trbk = sys.exc_info()
            errorName = cla.__name__
            try:
                excArgs = error.__dict__["args"]
            except KeyError:
                excArgs = "<no args>"
            errorDetail = traceback.format_tb(trbk, 5)
            errorDetails = str(errorName)+"\n"+str(error)+"\n"+str(excArgs)+"\n"+str(errorDetail[0])
            Dialogs.showError(translate("RunCommand", "Error: Failed To Run The Query"),
                        str(translate("RunCommand", "Error details: <br> \"%s\"")) % (errorDetails))
            return False
    
    def saveCommand(self):
        if str(codesOfUser())!=str(str(self.sciCommand.text())):
            answer = Dialogs.ask(translate("RunCommand", "Do You Wish To Save Your Codes?"), 
                            translate("RunCommand", "Do you wish to save your codes so that you can continue later?"), True)
            if answer==Dialogs.Yes:
                codesOfUser(str(self.sciCommand.text()))
            elif answer==Dialog.Cancel:
                return False
        return True

    def clear(self):
        answer = Dialogs.ask(translate("RunCommand", "Your Codes Will Be Deleted!.."), 
                            translate("RunCommand", "Your codes will be deleted and the default codes will be installed. Do you wish to clear the current codes?"))
        if answer==Dialogs.Yes:
            reFillCodesOfUser()
            self.sciCommand.setText(trForUI(codesOfUser()))
        
        
        



## This file is part of HamsiManager.
## 
## Copyright (c) 2010 Murat Demir <mopened@gmail.com>      
##
## Hamsi Manager is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
## 
## Hamsi Manager is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
## 
## You should have received a copy of the GNU General Public License
## along with HamsiManager; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA


from MyObjects import *
import Universals
import Dialogs
import InputOutputs
import Options

MyDialog, MyDialogType, MyParent = getMyDialog()

class FileTreeBuilder(MyDialog):
    def __init__(self, _directory):
        MyDialog.__init__(self, MyParent)
        if MyDialogType=="MDialog":
            if Universals.isActivePyKDE4==True:
                self.setButtons(MyDialog.NoDefault)
        elif MyDialogType=="MMainWindow":
            self.setObjectName("Packager")
            Universals.MainWindow = self
        newOrChangedKeys = Universals.newSettingsKeys + Universals.changedDefaultValuesKeys
        wOptionsPanel = Options.Options(None, "fileTree", None, newOrChangedKeys)
        lblDirectory = MLabel(translate("FileTreeBuilder", "Directory : "))
        lblOutputType = MLabel(translate("FileTreeBuilder", "Output Type : "))
        lblContentType = MLabel(translate("FileTreeBuilder", "Content Type : "))
        lblSubDirectoryDeepDetails = translate("FileTreeBuilder", "You can select sub directory deep.<br><font color=blue>You can select \"-1\" for all sub directories.</font>")
        lblSubDirectoryDeep = MLabel(translate("FileTreeBuilder", "Deep : "))
        self.cbSubDirectoryDeep = MComboBox(self)
        for x in range(-1, 10):
            self.cbSubDirectoryDeep.addItem(str(x))
        self.cbSubDirectoryDeep.setCurrentIndex(self.cbSubDirectoryDeep.findText(Universals.MySettings["subDirectoryDeep"]))
        self.cbSubDirectoryDeep.setToolTip(lblSubDirectoryDeepDetails)
        self.cbContentType = MComboBox()
        self.cbContentType.addItems([translate("FileTreeBuilder", "HTML"),
                                    translate("FileTreeBuilder", "Plain Text")])
        self.cbOutputType = MComboBox()
        self.cbOutputType.addItems([translate("FileTreeBuilder", "File"),
                                    translate("FileTreeBuilder", "Dialog"),
                                    translate("FileTreeBuilder", "Clipboard")])
        self.cbOutputType.setCurrentIndex(1)
        pbtnBuild = MPushButton(translate("FileTreeBuilder", "Build"))
        pbtnClose = MPushButton(translate("FileTreeBuilder", "Close"))
        self.lePath = MLineEdit(trForM(_directory))
        pbtnSelectPath = MPushButton(translate("FileTreeBuilder", "Browse"))
        self.connect(pbtnSelectPath,SIGNAL("clicked()"),self.selectPath)
        self.connect(pbtnBuild,SIGNAL("clicked()"), self.build)
        self.connect(pbtnClose,SIGNAL("clicked()"),self.close)
        pnlMain = MWidget(self)
        tabwTabs = MTabWidget()
        vblMain = MVBoxLayout(pnlMain)
        pnlMain2 = MWidget(tabwTabs)
        vblMain2 = MVBoxLayout(pnlMain2)
        HBox = MHBoxLayout()
        HBox.addWidget(self.lePath)
        HBox.addWidget(pbtnSelectPath)
        HBox1 = MHBoxLayout()
        HBox1.addWidget(pbtnBuild)
        HBox1.addWidget(pbtnClose)
        HBox2 = MHBoxLayout()
        HBox2.addWidget(lblOutputType)
        HBox2.addWidget(self.cbOutputType)
        HBox3 = MHBoxLayout()
        HBox3.addWidget(lblContentType)
        HBox3.addWidget(self.cbContentType)
        HBox4 = MHBoxLayout()
        HBox4.addWidget(lblSubDirectoryDeep)
        HBox4.addWidget(self.cbSubDirectoryDeep)
        vblMain2.addWidget(lblDirectory)
        vblMain2.addLayout(HBox)
        vblMain2.addLayout(HBox2)
        vblMain2.addLayout(HBox3)
        vblMain2.addLayout(HBox4)
        vblMain2.addStretch(1)
        vblMain2.addLayout(HBox1)
        tabwTabs.addTab(pnlMain2, translate("FileTreeBuilder", "File Tree"))
        tabwTabs.addTab(wOptionsPanel, translate("FileTreeBuilder", "Quick Options"))
        vblMain.addWidget(tabwTabs)
        if MyDialogType=="MDialog":
            if Universals.isActivePyKDE4==True:
                self.setMainWidget(pnlMain)
            else:
                self.setLayout(vblMain)
        elif MyDialogType=="MMainWindow":
            self.setCentralWidget(pnlMain)
            moveToCenter(self)
        self.setWindowTitle(translate("FileTreeBuilder", "File Tree Builder"))
        self.setWindowIcon(MIcon("Images:fileTree.png"))
        self.setMinimumWidth(450)
        self.show()
                        
    def closeEvent(self, _event):
        MApplication.setQuitOnLastWindowClosed(True)
    
    def build(self):
        try:
            Universals.isCanBeShowOnMainWindow = False
            outputType = "file"
            contentType = "html"
            if self.cbOutputType.currentIndex()==1:
                outputType = "dialog"
            elif self.cbOutputType.currentIndex()==2:
                outputType = "clipboard"
            if self.cbContentType.currentIndex()==1:
                contentType = "plainText"
            InputOutputs.IA.getFileTree(str(self.lePath.text()), 
                                self.cbSubDirectoryDeep.currentText(), 
                                outputType, contentType, "title")
            if self.cbOutputType.currentIndex()==2:
                Dialogs.show(translate("FileTreeBuilder", "Builded File Tree"),
                            translate("FileTreeBuilder", "File tree copied to clipboard."))
            Universals.isCanBeShowOnMainWindow = True
        except:
            import ReportBug
            error = ReportBug.ReportBug()
            error.show()   
    
    def selectPath(self):
        try:
            dirPath = MFileDialog.getExistingDirectory(self,
                            translate("FileTreeBuilder", "Please Select"),self.lePath.text())
            if dirPath!="":
                self.lePath.setText(dirPath)
        except:
            import ReportBug
            error = ReportBug.ReportBug()
            error.show() 
    
    
                



## This file is part of HamsiManager.
## 
## Copyright (c) 2010 Murat Demir <mopened@gmail.com>      
##
## Hamsi Manager is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
## 
## Hamsi Manager is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
## 
## You should have received a copy of the GNU General Public License
## along with HamsiManager; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA


import Variables
import Universals
from Databases import sqlite, getDefaultConnection, correctForSql, getAmendedSQLInsertOrUpdateQueries

class SearchAndReplaceTable:
    global fetchAll, fetch, checkValues, insert, update, delete
    global getTableCreateQuery, getDeleteTableQuery, getDefaultsQueries
    global tableName, tableVersion, allForFetch
    tableName = "searchAndReplaceTable"
    tableVersion = 2
    allForFetch = None
        
    def fetchAll():
        global allForFetch
        if allForFetch==None:
            con = getDefaultConnection()
            cur = con.cursor()
            cur.execute("SELECT * FROM " + tableName)
            allForFetch = cur.fetchall()
        return allForFetch
    
    def fetch(_id):
        con = getDefaultConnection()
        cur = con.cursor()
        cur.execute("SELECT * FROM " + tableName + " where id=" + str(int(_id)))
        return cur.fetchall()
    
    def checkValues(_searching, _replacing, _intIsActive, _intIsCaseSensitive, _intIsRegExp):
        if len(_searching)==0:
            return False
        return True
    
    def insert(_searching, _replacing, _intIsActive, _intIsCaseSensitive, _intIsRegExp):
        global allForFetch
        if checkValues(_searching, _replacing, _intIsActive, _intIsCaseSensitive, _intIsRegExp):
            allForFetch = None
            con = getDefaultConnection()
            cur = con.cursor()
            sqlQueries = getAmendedSQLInsertOrUpdateQueries(tableName, {"searching" : "'" + correctForSql(_searching) + "'", "replacing" : "'" + correctForSql(_replacing) + "'", "intIsActive" : correctForSql(_intIsActive), "intIsCaseSensitive" : correctForSql(_intIsCaseSensitive), "intIsRegExp" : correctForSql(_intIsRegExp)}, ["searching"])
            cur.execute(sqlQueries[0])
            cur.execute(sqlQueries[1])
            con.commit()
            cur.execute("SELECT last_insert_rowid();")
            return cur.fetchall()[0][0]
        return None
    
    def update(_id, _searching, _replacing, _intIsActive, _intIsCaseSensitive, _intIsRegExp):
        global allForFetch
        if checkValues(_searching, _replacing, _intIsActive, _intIsCaseSensitive, _intIsRegExp):
            allForFetch = None
            con = getDefaultConnection()
            cur = con.cursor()
            cur.execute(str("update " + tableName + " set searching='" + correctForSql(_searching) + "', replacing='" + correctForSql(_replacing) + "', intIsActive='" + correctForSql(_intIsActive) + "', intIsCaseSensitive='" + correctForSql(_intIsCaseSensitive) + "', intIsRegExp='" + correctForSql(_intIsRegExp) + "' where id=" + str(int(_id))))
            con.commit()
    
    def delete(_id):
        global allForFetch
        allForFetch = None
        con = getDefaultConnection()
        cur = con.cursor()
        cur.execute("delete from " + tableName + " where id="+str(int(_id)))
        con.commit()
        
    def getTableCreateQuery():
        return "CREATE TABLE IF NOT EXISTS " + tableName + " ('id' INTEGER PRIMARY KEY AUTOINCREMENT NOT NULL,'searching' TEXT,'replacing' TEXT,'intIsActive' INTEGER,'intIsCaseSensitive' INTEGER,'intIsRegExp' INTEGER)"
        
    def getDeleteTableQuery():
        return "DELETE FROM " + tableName
        
    def getDefaultsQueries():
        sqlQueries = []
        sqlQueries += getAmendedSQLInsertOrUpdateQueries(tableName, {"searching" : "'http://'", "replacing" : "''", "intIsActive" : "1", "intIsCaseSensitive" : "1", "intIsRegExp" : "0"}, ["searching"])
        sqlQueries += getAmendedSQLInsertOrUpdateQueries(tableName, {"searching" : "'www'", "replacing" : "''", "intIsActive" : "1", "intIsCaseSensitive" : "1", "intIsRegExp" : "0"}, ["searching"])
        return sqlQueries
        
    



## This file is part of HamsiManager.
## 
## Copyright (c) 2010 Murat Demir <mopened@gmail.com>      
##
## Hamsi Manager is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
## 
## Hamsi Manager is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
## 
## You should have received a copy of the GNU General Public License
## along with HamsiManager; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA


import InputOutputs
from MyObjects import *
from time import gmtime
import Dialogs
import Organizer
import Records
import Universals
import Taggers

class Musics:
    global readMusicFile, writeMusicFile
    
    def readMusicFile(_filePath):
        _directoryPath = InputOutputs.getDirName(_filePath)
        isCanNoncompatible = False
        if InputOutputs.IA.isReadableFileOrDir(_filePath):
            tagger = Taggers.getTagger()
            tagger.loadFile(_filePath)
            if tagger.isAvailableFile() == False:
                isCanNoncompatible=True
            content = {}
            content["path"] = _filePath
            content["baseNameOfDirectory"] = InputOutputs.getBaseName(_directoryPath)
            content["baseName"] = InputOutputs.getBaseName(_filePath)
            content["artist"] = tagger.getArtist()
            content["title"] = tagger.getTitle()
            content["album"] = tagger.getAlbum()
            content["trackNum"] = tagger.getTrackNum()
            content["year"] = tagger.getYear()
            content["genre"] = tagger.getGenre()
            content["firstComment"] = tagger.getFirstComment()
            content["firstLyrics"] = tagger.getFirstLyrics()
            content["size"] = tagger.getSize()
            content["playTimeString"] = tagger.getPlayTimeString()
            content["sampleFreq"] = tagger.getSampleFreq()
            content["bitRateString"] = tagger.getBitRateString()
            content["images"] = tagger.getImages()
            if isCanNoncompatible == True:
                Dialogs.show(translate("InputOutputs/Musics", "Possible ID3 Mismatch"),
                    translate("InputOutputs/Musics", "Some of the files presented in the table may not support ID3 technology.<br>Please check the files and make sure they support ID3 information before proceeding."))
            return content
    
    def writeMusicFile(_oldMusicTagsValues,_newMusicTagsValues,_isImageAction=False,_ImageType=False,_ImagePath=False):
        if InputOutputs.IA.isWritableFileOrDir(_oldMusicTagsValues["path"]):
            baseNameOfDirectory = _oldMusicTagsValues["baseNameOfDirectory"]
            baseName = _oldMusicTagsValues["baseName"]
            tagger = Taggers.getTagger()
            tagger.loadFileForWrite(_oldMusicTagsValues["path"])
            if _isImageAction==False:
                if _newMusicTagsValues["artist"]!=_oldMusicTagsValues["artist"]:
                    tagger.setArtist(str(_newMusicTagsValues["artist"]))
                if _newMusicTagsValues["title"]!=_oldMusicTagsValues["title"]:
                    tagger.setTitle(str(_newMusicTagsValues["title"]))
                if _newMusicTagsValues["album"]!=_oldMusicTagsValues["album"]:
                    tagger.setAlbum(str(_newMusicTagsValues["album"]))
                if _newMusicTagsValues["trackNum"]!=_oldMusicTagsValues["trackNum"]:
                    tagger.setTrackNum(int(_newMusicTagsValues["trackNum"]))
                if _newMusicTagsValues["year"]!=_oldMusicTagsValues["year"]:
                    tagger.setDate(str(_newMusicTagsValues["year"]))
                if _newMusicTagsValues["genre"]!=_oldMusicTagsValues["genre"]:
                    tagger.setGenre(str(_newMusicTagsValues["genre"]))
                if _newMusicTagsValues["firstComment"]!=_oldMusicTagsValues["firstComment"]:
                    tagger.setFirstComment(str(_newMusicTagsValues["firstComment"]))
                if _newMusicTagsValues["firstLyrics"]!=_oldMusicTagsValues["firstLyrics"]:
                    tagger.setFirstLyrics(str(_newMusicTagsValues["firstLyrics"]))
                tagger.update()
                if _newMusicTagsValues["baseNameOfDirectory"]!=_oldMusicTagsValues["baseNameOfDirectory"]:
                    baseNameOfDirectory = str(_newMusicTagsValues["baseNameOfDirectory"])
                if _newMusicTagsValues["baseName"]!=_oldMusicTagsValues["baseName"]:
                    baseName = str(_newMusicTagsValues["baseName"])
                newFilePath = InputOutputs.getDirName(InputOutputs.getDirName(_oldMusicTagsValues["path"])) + "/" + baseNameOfDirectory + "/" + baseName
                if InputOutputs.getRealPath(_oldMusicTagsValues["path"]) != InputOutputs.getRealPath(newFilePath):
                    return InputOutputs.moveOrChange(_oldMusicTagsValues["path"], newFilePath, InputOutputs.getObjectType(_oldMusicTagsValues["path"]))
            #Making changes on image files
            else:
                tagger.addImage(_ImageType,_ImagePath)
                tagger.update()
                return None
        return _oldMusicTagsValues["path"]
    
        



#!/usr/bin/env python
## This file is part of HamsiManager.
## 
## Copyright (c) 2010 Murat Demir <mopened@gmail.com>      
##
## Hamsi Manager is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
## 
## Hamsi Manager is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
## 
## You should have received a copy of the GNU General Public License
## along with HamsiManager; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

import sys
import os
if sys.path[0]=="":
    sys.path.insert(0, sys.path[1])
sys.path.insert(1,sys.path[0]+"/Core")
import Variables
try: 
    if Variables.isPython3k==False: 
        reload(sys)
        sys.setdefaultencoding("utf-8")
except:pass
Variables.checkStartupVariables()
import Universals
import RoutineChecks
if RoutineChecks.checkQt4Exist():
    myUniversals = ""
    if RoutineChecks.checkParameters():
        import Settings
        Settings.checkSettings()
        Universals.fillMySettings()
        Universals.printForDevelopers("Before MyObjects")
        from MyObjects import *
        Universals.printForDevelopers("Before InputOutputs")
        import InputOutputs
        if Universals.isActivePyKDE4==True:
            Universals.printForDevelopers("ActivePyKDE4")
            appName     = "HamsiManager"
            programName = ki18n ("Hamsi Manager")
            version     = Variables.version
            license     = MAboutData.License_GPL_V3
            copyright   = ki18n (trForUI("Murat Demir (mopened@gmail.com)"))
            kde4LangKode = str(KLocale(Variables.Catalog).language())+"_"+str(KLocale(Variables.Catalog).country()).upper()
            text        = ki18n (trForUI(""))
            homePage    = trForUI("hamsiapps.com")
            bugEmail    = trForUI("Murat Demir (mopened@gmail.com)")
            if InputOutputs.isFile(Variables.HamsiManagerDirectory+"/Languages/About_"+ kde4LangKode):
                aboutFileContent = InputOutputs.readFromFile(Variables.HamsiManagerDirectory+"/Languages/About_"+ kde4LangKode, "utf-8")
            else:
                aboutFileContent = InputOutputs.readFromFile(Variables.HamsiManagerDirectory+"/Languages/About_en_GB", "utf-8")
            description = ki18n (trForUI(aboutFileContent))
            Universals.printForDevelopers("Before MAboutData")
            aboutOfHamsiManager = MAboutData (appName, Variables.Catalog, programName, version, description,
                                    license, copyright, text, homePage, bugEmail)
            aboutOfHamsiManager.addAuthor (ki18n(trForUI("Murat Demir")), ki18n(trForUI("Project Manager and Developer")), 
                                "mopened@gmail.com", "hamsiapps.com")
            aboutOfHamsiManager.addCredit(ki18n(trForUI("Tolga Balc\xc4\xb1")), ki18n(trForUI("Translate to English. (Voluntary) (V0.7.x)")), 
                                            "tbalci@gmail.com", "http://www.brighthub.com/members/paladin.aspx")
            aboutOfHamsiManager.addCredit(ki18n(trForUI("M\xc3\xa1rcio Moraes")), ki18n(trForUI("Translate to Brazilian Portuguese. (Voluntary) (V0.8.7 - ~)")), 
                                            "", "")
            aboutOfHamsiManager.setProgramIconName(trForM(Universals.themePath + "/Images/HamsiManager-128x128.png"))
            if InputOutputs.isFile(Variables.HamsiManagerDirectory+"/Languages/License_"+ kde4LangKode):
                aboutOfHamsiManager.addLicenseTextFile(trForM(Variables.HamsiManagerDirectory+"/Languages/License_"+ kde4LangKode))
            else:
                aboutOfHamsiManager.addLicenseTextFile(trForM(Variables.HamsiManagerDirectory+"/Languages/License_en_GB"))
            Universals.printForDevelopers("Before MCmdLineArgs")
            MCmdLineArgs.init(sys.argv, aboutOfHamsiManager)
            options = MCmdLineOptions()
            for x in RoutineChecks.optionList:
                options.add(x, ki18n(x + " For Only PyKDE4 Requirement"))
            MCmdLineArgs.addCmdLineOptions(options)
            Universals.printForDevelopers("Before MApplication")
            HamsiManagerApp = MApplication()
            kde4LangKode = str(MGlobal.locale().language())
            if len(kde4LangKode)!=5: kde4LangKode += "_"+str(MGlobal.locale().country()).upper()
            if Variables.getInstalledLanguagesCodes().count(kde4LangKode)==0:
                for lcode in Variables.getInstalledLanguagesCodes():
                    if lcode.find(kde4LangKode[:2])!=-1:
                        kde4LangKode = lcode
            kconf = MGlobal.config()
            MGlobal.locale().setLanguage(kde4LangKode, kconf)
            if InputOutputs.isFile(Variables.HamsiManagerDirectory+"/Languages/HamsiManager_"+kde4LangKode+".qm"):
                languageFile = MTranslator()
                languageFile.load(trForM(Variables.HamsiManagerDirectory+"/Languages/HamsiManager_"+kde4LangKode+".qm"))
                HamsiManagerApp.installTranslator(languageFile)
            Variables.aboutOfHamsiManager = aboutOfHamsiManager
        else:
            Universals.printForDevelopers("NotActivePyKDE4")
            HamsiManagerApp = MApplication(sys.argv)  
            if InputOutputs.isFile(Variables.HamsiManagerDirectory+"/Languages/About_"+ Universals.MySettings["language"]):
                aboutFileContent = InputOutputs.readFromFile(Variables.HamsiManagerDirectory+"/Languages/About_"+ Universals.MySettings["language"], "utf-8")
            else:
                aboutFileContent = InputOutputs.readFromFile(Variables.HamsiManagerDirectory+"/Languages/About_en_GB", "utf-8")
            Variables.aboutOfHamsiManager = trForUI(aboutFileContent)
            if InputOutputs.isFile(Variables.HamsiManagerDirectory+"/Languages/HamsiManagerWithQt_"+Universals.MySettings["language"]+".qm"):
                languageFile = MTranslator()
                languageFile.load(trForM(Variables.HamsiManagerDirectory+"/Languages/HamsiManagerWithQt_"+Universals.MySettings["language"]+".qm"))
                HamsiManagerApp.installTranslator(languageFile)
            elif InputOutputs.isFile(Variables.HamsiManagerDirectory+"/Languages/HamsiManager_"+Universals.MySettings["language"]+".qm"):
                languageFile = MTranslator()
                languageFile.load(trForM(Variables.HamsiManagerDirectory+"/Languages/HamsiManager_"+Universals.MySettings["language"]+".qm"))
                HamsiManagerApp.installTranslator(languageFile)
        Universals.printForDevelopers("Before MTextCodec setCodecFor..")
        MTextCodec.setCodecForCStrings(MTextCodec.codecForName("utf-8"))
        MTextCodec.setCodecForTr(MTextCodec.codecForName("utf-8"))
        HamsiManagerApp.setApplicationName("HamsiManager")
        HamsiManagerApp.setApplicationVersion(Variables.version)
        HamsiManagerApp.setOrganizationDomain("hamsiapps.com")
        HamsiManagerApp.setOrganizationName("Hamsi Apps")
        MApplication.setQuitOnLastWindowClosed(True)
        MDir.setSearchPaths("Images", MStringList(trForM(Universals.themePath + "/Images/")))
        MDir.setSearchPaths("root", MStringList(trForM(Variables.HamsiManagerDirectory+"/")))
        if InputOutputs.isFile(Universals.themePath + "/Style.qss"):
            HamsiManagerApp.setStyleSheet(InputOutputs.readFromFile(Universals.themePath + "/Style.qss"))
        HamsiManagerApp.setWindowIcon(MIcon("Images:HamsiManager-128x128.png"))
        MApplication.setStyle(Universals.MySettings["applicationStyle"])
        if Universals.isActivePyKDE4:
            if InputOutputs.isFile(Universals.MySettings["colorSchemes"]):
                config = MSharedConfig.openConfig(Universals.MySettings["colorSchemes"])
                plt = MGlobalSettings.createApplicationPalette(config)
            else:
                plt = MApplication.desktop().palette()
            MApplication.setPalette(plt)
        Universals.printForDevelopers("Before RoutineChecks.checkMyModules")
        if RoutineChecks.checkMyModules(HamsiManagerApp):
            if RoutineChecks.isQuickMake:
                Universals.printForDevelopers("QuickMake")
                try:
                    myUniversals = Universals.Universals(HamsiManagerApp, None)
                    Universals.fillUIUniversals()
                    import QuickMake
                    quickMake = QuickMake.QuickMake()
                    if RoutineChecks.isQuickMake:
                        res = HamsiManagerApp.exec_()
                        Universals.printForDevelopers("Shutting down, result %d" % res)
                except:
                    import ReportBug
                    error = ReportBug.ReportBug()
                    error.show()
                    res = HamsiManagerApp.exec_()
                    Universals.printForDevelopers("Shutting down, result %d" % res)
            if RoutineChecks.isQuickMake == False:
                Universals.printForDevelopers("NotQuickMake")
                import SpecialTools
                import Tables
                import FileManager
                import Bars
                Universals.printForDevelopers("After Modules")
                try:
                    class Main(MMainWindow):
                        def __init__(self):
                            MMainWindow.__init__(self, None)
                            Universals.printForDevelopers("Started __init__")
                            self.setObjectName("RealMainWindow")
                            myUniversals = Universals.Universals(HamsiManagerApp, self)
                            Universals.fillUIUniversals()
                            self.Menu = None
                            self.CentralWidget = MWidget()
                            self.createMainLayout()
                            Universals.printForDevelopers("Before Bars.Bars")
                            self.Bars = Bars.Bars()
                            Universals.printForDevelopers("Before Bars.StatusBar")
                            self.StatusBar = Bars.StatusBar(self)
                            Universals.printForDevelopers("Before Bars.MenuBar")
                            self.Menu = Bars.MenuBar(self)
                            Universals.printForDevelopers("Before Bars.ToolsBar")
                            self.ToolsBar = Bars.ToolsBar(self)
                            Universals.printForDevelopers("Before Bars.TableToolsBar")
                            self.TableToolsBar = Bars.TableToolsBar(self)
                            Universals.printForDevelopers("Before Bars.refreshBars")
                            self.Bars.refreshBars()
                            Universals.printForDevelopers("Before FileManager.FileManager")
                            self.FileManager = FileManager.FileManager(self)
                            Universals.printForDevelopers("After FileManager.FileManager")
                            self.setMainLayout()
                            self.setCentralWidget(self.CentralWidget)
                            self.setMenuBar(self.Menu)
                            self.setStatusBar(self.StatusBar)
                            Universals.printForDevelopers("Before Menu.refreshForTableType")
                            self.Menu.refreshForTableType()
                            Universals.printForDevelopers("Before Bars.getAllBarsStyleFromMySettings")
                            self.Bars.getAllBarsStyleFromMySettings()
                            self.setCorner(Mt.TopLeftCorner, Mt.LeftDockWidgetArea)
                            self.setCorner(Mt.BottomLeftCorner, Mt.LeftDockWidgetArea)
                            Universals.printForDevelopers("End of __init__")
                            
                        def createMainLayout(self):
                            self.MainLayout = MVBoxLayout()
                            
                        def setMainLayout(self):
                            self.CentralWidget.setLayout(self.MainLayout)
                            
                        def resetCentralWidget(self):
                            Universals.clearAllChilds(self.CentralWidget)
                            self.MainLayout = self.CentralWidget.layout()
                            if self.MainLayout is None:
                                self.createMainLayout()
                                self.setMainLayout()
                            
                        def lockForm(self):
                            self.CentralWidget.setEnabled(False)
                            for wid in self.findChildren(MDockWidget):
                                wid.setEnabled(False)
                            for wid in self.findChildren(MToolBar):
                                wid.setEnabled(False)
                            for wid in self.findChildren(MMenuBar):
                                wid.setEnabled(False)
                            
                        def unlockForm(self):
                            self.CentralWidget.setEnabled(True)
                            for wid in self.findChildren(MDockWidget):
                                wid.setEnabled(True)
                            for wid in self.findChildren(MToolBar):
                                wid.setEnabled(True)
                            for wid in self.findChildren(MMenuBar):
                                wid.setEnabled(True)
                            
                        def closeEvent(self, _event):
                            try:
                                if Universals.isRaisedAnError==False:
                                    if Universals.isContinueThreadAction():
                                        Universals.cancelThreadAction()
                                        _event.ignore()
                                Universals.isStartedCloseProcces = True
                                Universals.printForDevelopers("Started closeEvent")
                                MApplication.setQuitOnLastWindowClosed(True)
                                try:self.PlayerBar.Player.stop()
                                except:pass
                                import ReportBug, Records
                                from Details import MusicDetails, TextDetails, CoverDetails
                                MusicDetails.closeAllMusicDialogs()
                                TextDetails.closeAllTextDialogs()
                                CoverDetails.closeAllCoverDialogs()
                                Universals.printForDevelopers("Closed Dialogs")
                                if Universals.isRaisedAnError==False:
                                    if self.Table.checkUnSavedValues()==False:
                                        Universals.isStartedCloseProcces=False
                                        Universals.printForDevelopers("Close ignored")
                                        _event.ignore() 
                                if Universals.isActivePyKDE4==True:
                                    Universals.printForDevelopers("Before Save KDE Configs")
                                    kconf = MGlobal.config()
                                    kconfGroup = MConfigGroup(kconf,"DirectoryOperator")
                                    self.FileManager.dirOperator.writeConfig(kconfGroup)
                                    self.FileManager.actCollection.writeSettings(kconfGroup)
                                    Universals.printForDevelopers("After Save KDE Configs")
                                Universals.printForDevelopers("Before Save Configs")
                                Universals.setMySetting(self.Table.SubTable.hiddenTableColumnsSettingKey,self.Table.hiddenTableColumns)
                                self.Bars.setAllBarsStyleToMySettings()
                                if ReportBug.iSClosingInErrorReporting == False:
                                    Records.setRecordType(1)
                                    subFixForStateFile = ""
                                    if Universals.windowMode!=Variables.windowModeKeys[0]:
                                        subFixForStateFile = Universals.windowMode
                                    InputOutputs.writeToBinaryFile(Universals.pathOfSettingsDirectory + "/LastState" + subFixForStateFile, self.saveState())
                                    Records.restoreRecordType()
                                    geometri = [self.geometry().x(), self.geometry().y(), self.geometry().width(), self.geometry().height()]
                                    Universals.setMySetting("MainWindowGeometries",geometri)
                                Universals.setMySetting("lastDirectory",self.FileManager.currentDirectory)
                                Universals.setMySetting("isMainWindowMaximized",self.isMaximized())
                                Universals.setMySetting("isShowAdvancedSelections",self.SpecialTools.isShowAdvancedSelections)
                                if Universals.tableType==2:
                                    Universals.setMySetting("isRunOnDoubleClick",self.Table.tbIsRunOnDoubleClick.isChecked())
                                    Universals.setMySetting("isOpenDetailsInNewWindow",self.Table.isOpenDetailsOnNewWindow.isChecked())
                                    Universals.setMySetting("isPlayNow",self.Table.SubTable.isPlayNow.isChecked())
                                Universals.setMySetting("isChangeSelected",Universals.isChangeSelected)
                                Universals.setMySetting("isChangeAll",Universals.isChangeAll)
                                Universals.setMySetting("tableType", Universals.tableType)
                                Universals.setMySetting("activeTabNoOfSpecialTools", self.SpecialTools.tabwTabs.currentIndex())
                                Universals.saveSettings()
                                Settings.saveUniversalSettings()
                                if Universals.getBoolValue("amarokIsUseHost")==False:
                                    import Amarok
                                    Amarok.stopEmbeddedDB()
                                Universals.printForDevelopers("After Save Configs")
                                Universals.printForDevelopers("Before RoutineChecks.checkAfterCloseProccess")
                                RoutineChecks.checkAfterCloseProccess()
                                Universals.printForDevelopers("After RoutineChecks.checkAfterCloseProccess")
                            except:
                                import ReportBug
                                if ReportBug.isClose==False:
                                    error = ReportBug.ReportBug()
                                    error.show()
                                    _event.ignore()
                    
                    Universals.printForDevelopers("Before Main")
                    MainWindow=Main()
                    Universals.printForDevelopers("After Main")
                    MainWindow.setWindowTitle("Hamsi Manager "+ MApplication.applicationVersion())
                    if Universals.isActivePyKDE4==True:
                        Universals.printForDevelopers("Before MGlobal.config")
                        kconf = MGlobal.config()
                        kconfGroup = MConfigGroup(kconf,"Universals")
                        MainWindow.setAutoSaveSettings(kconfGroup)
                        Universals.printForDevelopers("After MGlobal.config")
                    else:
                        try:
                            Universals.printForDevelopers("Before MainWindow.restoreState")
                            state = MByteArray()
                            subFixForStateFile = ""
                            if Universals.windowMode!=Variables.windowModeKeys[0]:
                                subFixForStateFile = Universals.windowMode
                            state.append(InputOutputs.readFromBinaryFile(Universals.pathOfSettingsDirectory + "/LastState" + subFixForStateFile))
                            MainWindow.restoreState(state)
                            Universals.printForDevelopers("After MainWindow.restoreState")
                        except:pass
                    Universals.printForDevelopers("Before Show")
                    if Universals.getBoolValue("isMainWindowMaximized"):
                        MainWindow.showMaximized()
                    else:
                        geometries = Universals.getListFromStrint(Universals.MySettings["MainWindowGeometries"])
                        MainWindow.setGeometry(int(geometries[0]),int(geometries[1]), int(geometries[2]),int(geometries[3]))
                        MainWindow.show()
                    Universals.printForDevelopers("Before RoutineChecks.checkAfterRunProccess")
                    RoutineChecks.checkAfterRunProccess()
                    Universals.printForDevelopers("After RoutineChecks.checkAfterRunProccess")
                    Universals.setMySetting("isMakeAutoDesign", "False")
                    Universals.setMySetting("isShowReconfigureWizard", "False")
                    Universals.isStartingSuccessfully = True
                    Universals.isCanBeShowOnMainWindow = True
                except:
                    import ReportBug
                    error = ReportBug.ReportBug()
                    error.show()
                res = None
                try:
                    Universals.printForDevelopers("Before HamsiManagerApp.exec_")
                    res = HamsiManagerApp.exec_()
                    Universals.printForDevelopers("Shutting down, result %d" % res)
                except Exception as err:
                    import ReportBug
                    error = ReportBug.ReportBug()
                    error.show()
                    print (str(MApplication.translate("ReportBug", "A critical error has occurred.If you want to look into details \"%s\" you can see the file.If possible, we ask you to send us this error details." )) % (error.pathOfReportFile))
                    print (str(MApplication.translate("ReportBug", "Thanks in advance for your interest.")))
                    print ("Shutting down, result %d" % res)
                    raise err
                    
sys.exit()




## This file is part of HamsiManager.
## 
## Copyright (c) 2010 Murat Demir <mopened@gmail.com>      
##
## Hamsi Manager is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
## 
## Hamsi Manager is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
## 
## You should have received a copy of the GNU General Public License
## along with HamsiManager; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA


import InputOutputs
import os,sys
from MyObjects import *
import Dialogs
import Organizer
import Universals

class ImageViewer(MWidget):
    def __init__(self, _parent, _image = None, _valueType="file", _isCorrectedWhenNotExist=False, _defaultMaxSize=[150, 150]):
        MWidget.__init__(self, _parent)
        self.defaultMaxSize = _defaultMaxSize
        self.isCorrectedWhenNotExist = _isCorrectedWhenNotExist
        self.lblImage = MLabel()
        self.lblImage.setAlignment(Mt.AlignHCenter)
        self.lblImage.setScaledContents(True)
        self.pmapImage = MPixmap()
        self.changeCoverValues(_image, _valueType)
        scraMain = MScrollArea()
        scraMain.setWidget(self.lblImage)
        scraMain.setFrameShape(MFrame.NoFrame)
        scraMain.setAlignment(Mt.AlignHCenter)
        self.pbtnGoOriginalImageZoom = MPushButton(translate("ImageDetails", "1:1"))
        self.pbtnGoOriginalImageZoom.setMaximumWidth(100)
        MObject.connect(self.pbtnGoOriginalImageZoom, SIGNAL("clicked()"), self.goOriginalImageZoom)
        self.pbtnZoomOut = MPushButton(translate("ImageDetails", "-"))
        self.pbtnZoomOut.setMaximumWidth(30)
        MObject.connect(self.pbtnZoomOut, SIGNAL("clicked()"), self.zoomOut)
        self.pbtnZoomIn = MPushButton(translate("ImageDetails", "+"))
        self.pbtnZoomIn.setMaximumWidth(30)
        MObject.connect(self.pbtnZoomIn, SIGNAL("clicked()"), self.zoomIn)
        HBOXs = []
        HBOXs.append(MHBoxLayout())
        HBOXs[0].addWidget(self.pbtnGoOriginalImageZoom)
        HBOXs[0].addWidget(self.pbtnZoomOut)
        HBOXs[0].addWidget(self.pbtnZoomIn)
        self.pnlMain = MWidget()
        vblMain = MVBoxLayout(self.pnlMain)
        vblMain.addWidget(scraMain)
        vblMain.addLayout(HBOXs[0])
        self.setLayout(vblMain)
        self.show()
                  
    def changeCoverValues(self, _image=None, _valueType="file"):
        self.zoomValue = 1.0
        if _image!=None and _valueType=="file":
            if InputOutputs.IA.isFile(_image)==False:
                if self.isCorrectedWhenNotExist==True:
                    _image = Universals.themePath + "/Images/ok.png"
                else:
                    _image = Universals.themePath + "/Images/notExist.png"
        elif _valueType=="file":
            _image = Universals.themePath + "/Images/notExist.png"
        self.pmapImage.detach()
        if _valueType=="data":
            self.pmapImage.loadFromData(_image)
        else:
            self.pmapImage.load(trForM(_image))
        self.lblImage.setPixmap(self.pmapImage)
        self.width = self.pmapImage.width()
        self.height = self.pmapImage.height()
        while 1==1:
            if self.width>self.defaultMaxSize[0] or self.height>self.defaultMaxSize[1]:
                self.width*=0.9
                self.height*=0.9
            else:
                break
        self.lblImage.resize(int(self.width),int(self.height))

    def goOriginalImageZoom(self):
        self.makeZoom(1)
    
    def zoomOut(self):
        self.makeZoom(-0.1)
    
    def zoomIn(self):
        self.makeZoom(0.1)
        
    def makeZoom(self, _value):
        if _value==1:
            self.zoomValue = 1.0
            self.width = self.pmapImage.width()
            self.height = self.pmapImage.height()
            self.lblImage.resize(self.width, self.height)
        else:
            self.zoomValue += _value
            self.lblImage.resize(self.width*self.zoomValue, self.height*self.zoomValue)
    
    
     
     



## This file is part of HamsiManager.
## 
## Copyright (c) 2010 Murat Demir <mopened@gmail.com>      
##
## Hamsi Manager is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
## 
## Hamsi Manager is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
## 
## You should have received a copy of the GNU General Public License
## along with HamsiManager; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

import Organizer
import InputOutputs
import SearchEngines
from MyObjects import *
from Details import MusicDetails
import Universals
import Dialogs
import Taggers
from time import gmtime
import Records

class Content():
    global readContents, writeContents
    
    def readContents(_directoryPath):
        currentTableContentValues = []
        Universals.startThreadAction()
        import Amarok
        Dialogs.showState(translate("AmarokCoverTable", "Checking For Amarok..."), 0, 2)
        if Amarok.checkAmarok():
            Dialogs.showState(translate("AmarokCoverTable", "Getting Values From Amarok"), 1, 2)
            isContinueThreadAction = Universals.isContinueThreadAction()
            if isContinueThreadAction:
                from Amarok import Operations
                musicFileValuesWithNames = Operations.getAllMusicFileValuesWithNames()
                Dialogs.showState(translate("AmarokCoverTable", "Values Are Being Processed"), 2, 2)
                isContinueThreadAction = Universals.isContinueThreadAction()
                if isContinueThreadAction:
                    if musicFileValuesWithNames!=None:
                        allItemNumber = len(musicFileValuesWithNames)
                        musicFileNo = 0
                        for musicFileRow in musicFileValuesWithNames:
                            isContinueThreadAction = Universals.isContinueThreadAction()
                            if isContinueThreadAction:
                                if Amarok.getSelectedTagSourseType()=="Amarok":
                                    content = {}
                                    content["path"] = musicFileRow["filePath"]
                                    content["baseNameOfDirectory"] = InputOutputs.getBaseName(InputOutputs.getDirName(musicFileRow["filePath"]))
                                    content["baseName"] = InputOutputs.getBaseName(musicFileRow["filePath"])
                                    content["artist"] = musicFileRow["artist"]
                                    content["title"] = musicFileRow["title"]
                                    content["album"] = musicFileRow["album"]
                                    content["trackNum"] = musicFileRow["tracknumber"]
                                    content["year"] = musicFileRow["year"]
                                    content["genre"] = musicFileRow["genre"]
                                    content["firstComment"] = musicFileRow["comment"]
                                    content["firstLyrics"] = musicFileRow["lyrics"]
                                    currentTableContentValues.append(content)
                                else:
                                    if InputOutputs.IA.isFile(musicFileRow["filePath"]) and InputOutputs.IA.isReadableFileOrDir(musicFileRow["filePath"]):
                                        tagger = Taggers.getTagger()
                                        tagger.loadFile(musicFileRow["filePath"])
                                        content = {}
                                        content["path"] = musicFileRow["filePath"]
                                        content["baseNameOfDirectory"] = InputOutputs.getBaseName(InputOutputs.getDirName(musicFileRow["filePath"]))
                                        content["baseName"] = InputOutputs.getBaseName(musicFileRow["filePath"])
                                        content["artist"] = tagger.getArtist()
                                        content["title"] = tagger.getTitle()
                                        content["album"] = tagger.getAlbum()
                                        content["trackNum"] = tagger.getTrackNum()
                                        content["year"] = tagger.getYear()
                                        content["genre"] = tagger.getGenre()
                                        content["firstComment"] = tagger.getFirstComment()
                                        content["firstLyrics"] = tagger.getFirstLyrics()
                                        currentTableContentValues.append(content)
                            else:
                                allItemNumber = musicFileNo+1
                            Dialogs.showState(translate("InputOutputs/Covers", "Reading Music File Informations"),
                                              musicFileNo+1,allItemNumber, True) 
                            musicFileNo += 1
                            if isContinueThreadAction==False:
                                break
        Universals.finishThreadAction()
        return currentTableContentValues
    
    def writeContents(_table):
        _table.changedValueNumber = 0
        changingFileDirectories=[]
        changingTags=[]
        Universals.startThreadAction()
        import Amarok
        allItemNumber = len(_table.currentTableContentValues)
        Dialogs.showState(translate("InputOutputs/Musics", "Writing Music Tags"),0,allItemNumber, True)
        for rowNo in range(_table.rowCount()):
            isContinueThreadAction = Universals.isContinueThreadAction()
            if isContinueThreadAction:
                changingTags.append({"path" : _table.currentTableContentValues[rowNo]["path"]})
                isWritableFileOrDir = InputOutputs.IA.isFile(_table.currentTableContentValues[rowNo]["path"]) and InputOutputs.IA.isWritableFileOrDir(_table.currentTableContentValues[rowNo]["path"])
                if isWritableFileOrDir:
                    if _table.isRowHidden(rowNo):
                        InputOutputs.IA.removeFileOrDir(_table.currentTableContentValues[rowNo]["path"])
                        continue
                    baseNameOfDirectory = str(_table.currentTableContentValues[rowNo]["baseNameOfDirectory"])
                    baseName = str(_table.currentTableContentValues[rowNo]["baseName"])
                    if Amarok.getSelectedTagTargetType().find("ID3")>-1:
                        typeTemp = Amarok.getSelectedTagTargetType().split(" + ")
                        if len(typeTemp)>1:
                            taggerType = typeTemp[1]
                        else:
                            taggerType = typeTemp[0]
                        Taggers.setSelectedTaggerTypeName(taggerType)
                    tagger = Taggers.getTagger()
                    tagger.loadFileForWrite(_table.currentTableContentValues[rowNo]["path"])
                if _table.isChangableItem(rowNo, 2):
                    value = str(_table.item(rowNo,2).text())
                    if isWritableFileOrDir:tagger.setArtist(value)
                    changingTags[-1]["artist"] = value
                    Records.add(str(translate("AmarokMusicTable", "Artist")), str(_table.currentTableContentValues[rowNo]["artist"]), value)
                    _table.changedValueNumber += 1
                if _table.isChangableItem(rowNo, 3):
                    value = str(_table.item(rowNo,3).text())
                    if isWritableFileOrDir:tagger.setTitle(value)
                    changingTags[-1]["title"] = value
                    Records.add(str(translate("AmarokMusicTable", "Title")), str(_table.currentTableContentValues[rowNo]["title"]), value)
                    _table.changedValueNumber += 1
                if _table.isChangableItem(rowNo, 4):
                    value = str(_table.item(rowNo,4).text())
                    if isWritableFileOrDir:tagger.setAlbum(value)
                    changingTags[-1]["album"] = value
                    Records.add(str(translate("AmarokMusicTable", "Album")), str(_table.currentTableContentValues[rowNo]["album"]), value)
                    _table.changedValueNumber += 1
                if _table.isChangableItem(rowNo, 5):
                    value = str(_table.item(rowNo,5).text())
                    if isWritableFileOrDir:tagger.setTrackNum(value, len(_table.currentTableContentValues))
                    changingTags[-1]["trackNum"] = value
                    Records.add(str(translate("AmarokMusicTable", "Track No")), str(_table.currentTableContentValues[rowNo]["trackNum"]), value)
                    _table.changedValueNumber += 1
                if _table.isChangableItem(rowNo, 6):
                    value = str(_table.item(rowNo,6).text())
                    if isWritableFileOrDir:tagger.setDate(value)
                    changingTags[-1]["year"] = value
                    Records.add(str(translate("AmarokMusicTable", "Year")), str(_table.currentTableContentValues[rowNo]["year"]), value)
                    _table.changedValueNumber += 1
                if _table.isChangableItem(rowNo, 7):
                    value = str(_table.item(rowNo,7).text())
                    if isWritableFileOrDir:tagger.setGenre(value)
                    changingTags[-1]["genre"] = value
                    Records.add(str(translate("AmarokMusicTable", "Genre")), str(_table.currentTableContentValues[rowNo]["genre"]), value)
                    _table.changedValueNumber += 1
                if _table.isChangableItem(rowNo, 8):
                    value = str(_table.item(rowNo,8).text())
                    if isWritableFileOrDir:tagger.setFirstComment(value)
                    changingTags[-1]["firstComment"] = value
                    Records.add(str(translate("AmarokMusicTable", "Comment")), str(_table.currentTableContentValues[rowNo]["firstComment"]), value)
                    _table.changedValueNumber += 1
                if len(_table.tableColumns)>9 and _table.isChangableItem(rowNo, 9):
                    value = str(_table.item(rowNo,9).text())
                    if isWritableFileOrDir:tagger.setFirstLyrics(value)
                    changingTags[-1]["firstLyrics"] = value
                    Records.add(str(translate("AmarokMusicTable", "Lyrics")), str(_table.currentTableContentValues[rowNo]["firstLyrics"]), value)
                    _table.changedValueNumber += 1
                if isWritableFileOrDir:
                    if Amarok.getSelectedTagTargetType().find("ID3")>-1:
                        tagger.update()
                    if _table.isChangableItem(rowNo, 0, baseNameOfDirectory):
                        baseNameOfDirectory = str(_table.item(rowNo,0).text())
                        _table.changedValueNumber += 1
                    if _table.isChangableItem(rowNo, 1, baseName, False):
                        baseName = str(_table.item(rowNo,1).text())
                        _table.changedValueNumber += 1
                    newFilePath = InputOutputs.getDirName(InputOutputs.getDirName(_table.currentTableContentValues[rowNo]["path"])) + "/" + baseNameOfDirectory + "/" + baseName
                    if InputOutputs.getRealPath(_table.currentTableContentValues[rowNo]["path"]) != InputOutputs.getRealPath(newFilePath):
                        changingFileDirectories.append([_table.currentTableContentValues[rowNo]["path"], 
                                                        newFilePath])
            else:
                allItemNumber = rowNo+1
            Dialogs.showState(translate("InputOutputs/Musics", "Writing Music Tags"),rowNo+1,allItemNumber, True)
            if isContinueThreadAction==False:
                break
        Universals.finishThreadAction()
        pathValues = InputOutputs.IA.changeDirectories(changingFileDirectories)
        from Amarok import Operations
        if Amarok.getSelectedTagTargetType().find("Amarok")>-1:
            Operations.changeTags(changingTags)
        Operations.changePaths(pathValues)
        return True



class AmarokMusicTable():
    def __init__(self, _table):
        self.Table = _table
        self.specialTollsBookmarkPointer = "music"
        self.hiddenTableColumnsSettingKey = "hiddenAmarokMusicTableColumns"
        self.refreshColumns()
        pbtnVerifyTableValues = MPushButton(translate("AmarokMusicTable", "Verify Table"))
        pbtnVerifyTableValues.setMenu(SearchEngines.SearchEngines(self.Table))
        self.Table.mContextMenu.addMenu(SearchEngines.SearchEngines(self.Table, True))
        self.isPlayNow = MToolButton()
        self.isPlayNow.setToolTip(translate("AmarokMusicTable", "Play Now"))
        self.isPlayNow.setIcon(MIcon("Images:playNow.png"))
        self.isPlayNow.setCheckable(True)
        self.isPlayNow.setAutoRaise(True)
        self.isPlayNow.setChecked(Universals.getBoolValue("isPlayNow"))
        self.Table.hblBox.insertWidget(self.Table.hblBox.count()-3, self.isPlayNow)
        self.Table.hblBox.insertWidget(self.Table.hblBox.count()-1, pbtnVerifyTableValues)
        
    def showDetails(self, _fileNo, _infoNo):
        MusicDetails.MusicDetails(self.Table.currentTableContentValues[_fileNo]["path"],
                                      self.Table.isOpenDetailsOnNewWindow.isChecked(), self.isPlayNow.isChecked())
    
    def cellClicked(self,_row,_column):
        cellLenght = len(self.Table.currentItem().text())*8
        if cellLenght>self.Table.columnWidth(_column):
            self.Table.setColumnWidth(_column,cellLenght)
        if _column==8 or _column==9:
            if self.Table.rowHeight(_row)<150:
                self.Table.setRowHeight(_row,150)
            if self.Table.columnWidth(_column)<250:
                self.Table.setColumnWidth(_column,250)
        
    def cellDoubleClicked(self,_row,_column):
        try:
            if _column==8 or _column==9:
                self.showDetails(_row, _column)
            else:
                if self.Table.tbIsRunOnDoubleClick.isChecked()==True:
                    self.showDetails(_row, _column)
        except:
            Dialogs.showError(translate("AmarokMusicTable", "Cannot Open Music File"), 
                        str(translate("AmarokMusicTable", "\"%s\" : cannot be opened. Please make sure that you selected a music file.")
                        ) % Organizer.getLink(self.Table.currentTableContentValues[_row]["path"]))
       
    def refreshColumns(self):
        self.Table.tableColumns = Taggers.getAvailableLabelsForTable()
        self.Table.tableColumnsKey = Taggers.getAvailableKeysForTable()
        
    def save(self):
        MusicDetails.closeAllMusicDialogs()
        self.Table.checkFileExtensions(1, "baseName")
        return writeContents(self.Table)
        
    def refresh(self, _path):
        self.Table.setColumnWidth(5,70)
        self.Table.setColumnWidth(6,40)
        self.Table.currentTableContentValues = readContents(_path)
        self.Table.setRowCount(len(self.Table.currentTableContentValues))
        for rowNo in range(self.Table.rowCount()):
            for itemNo in range(len(self.Table.tableColumns)):
                item = None
                if itemNo==0:
                    newString = Organizer.emend(self.Table.currentTableContentValues[rowNo]["baseNameOfDirectory"], "directory")
                    item = self.Table.createTableWidgetItem(newString, self.Table.currentTableContentValues[rowNo]["baseNameOfDirectory"])
                elif itemNo==1:
                    newString = Organizer.emend(self.Table.currentTableContentValues[rowNo]["baseName"], "file")
                    item = self.Table.createTableWidgetItem(newString, self.Table.currentTableContentValues[rowNo]["baseName"])
                elif itemNo==2:
                    newString = Organizer.emend(self.Table.currentTableContentValues[rowNo]["artist"])
                    item = self.Table.createTableWidgetItem(newString, self.Table.currentTableContentValues[rowNo]["artist"])
                elif itemNo==3:
                    newString = Organizer.emend(self.Table.currentTableContentValues[rowNo]["title"])
                    item = self.Table.createTableWidgetItem(newString, self.Table.currentTableContentValues[rowNo]["title"])
                elif itemNo==4:
                    newString = Organizer.emend(self.Table.currentTableContentValues[rowNo]["album"])
                    item = self.Table.createTableWidgetItem(newString, self.Table.currentTableContentValues[rowNo]["album"])
                elif itemNo==5:
                    newString_temp = str(self.Table.currentTableContentValues[rowNo]["trackNum"]).split("/")
                    if newString_temp[0]=="None":
                        newString_temp[0]=str(rowNo+1)
                    newString = newString_temp[0]
                    newString += "/"+str(len(self.Table.currentTableContentValues))
                    item = self.Table.createTableWidgetItem(newString, self.Table.currentTableContentValues[rowNo]["trackNum"])
                elif itemNo==6:
                    newString = Organizer.emend(self.Table.currentTableContentValues[rowNo]["year"])
                    item = self.Table.createTableWidgetItem(newString, self.Table.currentTableContentValues[rowNo]["year"])
                elif itemNo==7:
                    newString = Organizer.emend(self.Table.currentTableContentValues[rowNo]["genre"])
                    item = self.Table.createTableWidgetItem(newString, self.Table.currentTableContentValues[rowNo]["genre"])
                elif itemNo==8:
                    newString = Organizer.emend(self.Table.currentTableContentValues[rowNo]["firstComment"])
                    item = self.Table.createTableWidgetItem(newString, self.Table.currentTableContentValues[rowNo]["firstComment"])
                elif itemNo==9:
                    newString = Organizer.emend(self.Table.currentTableContentValues[rowNo]["firstLyrics"])
                    item = self.Table.createTableWidgetItem(newString, self.Table.currentTableContentValues[rowNo]["firstLyrics"])
                if item!=None:
                    self.Table.setItem(rowNo, itemNo, item)
                        
    def correctTable(self):
        for rowNo in range(self.Table.rowCount()):
            for itemNo in range(self.Table.columnCount()):
                if itemNo==0:
                    newString = Organizer.emend(str(self.Table.item(rowNo,itemNo).text()), "directory")
                elif itemNo==1:
                    newString = Organizer.emend(str(self.Table.item(rowNo,itemNo).text()), "file")
                else:
                    newString = Organizer.emend(str(self.Table.item(rowNo,itemNo).text()))
                self.Table.item(rowNo,itemNo).setText(trForUI(newString))
                



## This file is part of HamsiManager.
## 
## Copyright (c) 2010 Murat Demir <mopened@gmail.com>      
##
## Hamsi Manager is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
## 
## Hamsi Manager is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
## 
## You should have received a copy of the GNU General Public License
## along with HamsiManager; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA


import os,sys
from MyObjects import *
from Viewers import ImageViewer
import Dialogs
import Organizer
import Universals

class CoverDetails(MDialog):
    global coverDialogs,closeAllCoverDialogs
    coverDialogs = []
    def __init__(self, _coverValues, _isOpenDetailsOnNewWindow=True, _FocusedInfoNo=None):
        """_coverValues[0] = Directory Path
        _coverValues[1] = Current Cover Path
        _coverValues[2] = Source Cover Path
        _coverValues[3] = Destination Cover Path
        """
        global coverDialogs
        if _isOpenDetailsOnNewWindow==False:
            isHasOpenedDialog=False
            for dialog in coverDialogs:
                if dialog.isVisible()==True:
                    isHasOpenedDialog=True
                    self = dialog
                    self.changeCoverValues(_coverValues)
                    dialog.activateWindow()
                    dialog.raise_()
                    break
            if isHasOpenedDialog==False:
                _isOpenDetailsOnNewWindow=True
        if _isOpenDetailsOnNewWindow==True:
            coverDialogs.append(self)
            MDialog.__init__(self, MApplication.activeWindow())
            if Universals.isActivePyKDE4==True:
                self.setButtons(MDialog.NoDefault)
            self.vblCurrent = MVBoxLayout()
            self.vblSource = MVBoxLayout()
            self.vblDestination = MVBoxLayout()
            self.lePathOfCurrent = MLineEdit(self)
            self.lePathOfSource = MLineEdit(self)
            self.lePathOfDestination = MLineEdit(self)
            self.wCurrent = ImageViewer.ImageViewer(self)
            self.wSource = ImageViewer.ImageViewer(self)
            self.wDestination = ImageViewer.ImageViewer(self, None, _isCorrectedWhenNotExist=True)
            self.wCurrent.setMinimumWidth(170)
            self.wSource.setMinimumWidth(170)
            self.wDestination.setMinimumWidth(170)
            self.wCurrent.setMinimumHeight(190)
            self.wSource.setMinimumHeight(190)
            self.wDestination.setMinimumHeight(190)
            self.vblCurrent.insertWidget(0, self.wCurrent, 1)
            self.vblSource.insertWidget(0, self.wSource, 1)
            self.vblDestination.insertWidget(0, self.wDestination, 1)
            self.changeCoverValues(_coverValues)
            pbtnClose = MPushButton(translate("ImageDetails", "OK"))
            pbtnClose.setFocus()
            pbtnClose.setMaximumWidth(150)
            MObject.connect(pbtnClose, SIGNAL("clicked()"), self.close)
            self.pbtnSource = MPushButton(translate("ImageDetails", "..."))
            self.pbtnSource.setMaximumWidth(30)
            MObject.connect(self.pbtnSource, SIGNAL("clicked()"), self.sourceClicked)
            self.pbtnDestination = MPushButton(translate("ImageDetails", "..."))
            self.pbtnDestination.setMaximumWidth(30)
            MObject.connect(self.pbtnDestination, SIGNAL("clicked()"), self.destinationClicked)
            MObject.connect(self.lePathOfSource, SIGNAL("textChanged(const QString&)"), self.sourceChanged)
            MObject.connect(self.lePathOfDestination, SIGNAL("textChanged(const QString&)"), self.destinationChanged)
            self.lePathOfCurrent.setEnabled(False)
            self.hblImages = MHBoxLayout()
            self.hblImages.addLayout(self.vblCurrent)
            self.hblImages.addLayout(self.vblSource)
            self.hblImages.addLayout(self.vblDestination)
            hblPathOfSource = MHBoxLayout()
            hblPathOfDestination = MHBoxLayout()
            HBOXs = []
            HBOXs.append(MHBoxLayout())
            self.vblCurrent.addWidget(self.lePathOfCurrent)
            hblPathOfSource.addWidget(self.lePathOfSource)
            hblPathOfDestination.addWidget(self.lePathOfDestination)
            hblPathOfSource.addWidget(self.pbtnSource)
            hblPathOfDestination.addWidget(self.pbtnDestination)
            self.vblSource.addLayout(hblPathOfSource)
            self.vblDestination.addLayout(hblPathOfDestination)
            HBOXs[0].addStretch(1)
            HBOXs[0].addWidget(pbtnClose)
            self.pnlMain = MWidget()
            vblMain = MVBoxLayout(self.pnlMain)
            vblMain.addLayout(self.hblImages)
            vblMain.addLayout(HBOXs[0])
            if Universals.isActivePyKDE4==True:
                self.setMainWidget(self.pnlMain)
            else:
                self.setLayout(vblMain)
            self.show()
                  
    def changeCoverValues(self, _coverValues):
        if _coverValues[1].strip()=="/": _coverValues[1] = _coverValues[0] + "/"
        if _coverValues[2].strip()=="/": _coverValues[2] = _coverValues[0] + "/"
        if _coverValues[3].strip()=="/": _coverValues[3] = _coverValues[0] + "/"
        self.setWindowTitle(trForUI(str(translate("ImageDetails", "Cover Details ( %s )")) % (_coverValues[0])))
        self.lePathOfCurrent.setText(trForUI(_coverValues[1]))
        self.lePathOfSource.setText(trForUI(_coverValues[2]))
        self.lePathOfDestination.setText(trForUI(_coverValues[3]))
        self.wCurrent.changeCoverValues(_coverValues[1])
        self.wSource.changeCoverValues(_coverValues[2])
        self.wDestination.changeCoverValues(_coverValues[3])
        
    def sourceChanged(self):
        self.wSource.changeCoverValues(str(self.lePathOfSource.text()))
        
    def destinationChanged(self):
        self.wDestination.changeCoverValues(str(self.lePathOfDestination.text()))
        
    def sourceClicked(self):
        imagePath = MFileDialog.getOpenFileName(self,translate("ImageDetails", "Choose Image"),
                                    self.lePathOfSource.text(),trForUI(str(translate("ImageDetails", "Images (*.%s)")) % Universals.getStrintFromList(Universals.getListFromStrint(Universals.MySettings["imageExtensions"])).replace(";", " *.")))
        if imagePath!="":
            self.lePathOfSource.setText(imagePath)
        
    def destinationClicked(self):
        imagePath = MFileDialog.getSaveFileName(self,translate("ImageDetails", "Save As"),
                                    self.lePathOfDestination.text(),trForUI(str(translate("ImageDetails", "Images (*.%s)")) % Universals.getStrintFromList(Universals.getListFromStrint(Universals.MySettings["imageExtensions"])).replace(";", " *.")))
        if imagePath!="":
            self.lePathOfDestination.setText(imagePath)
        
    def closeAllCoverDialogs():
        for dialog in coverDialogs:
            try:
                if dialog.isVisible()==True:
                    dialog.close()
            except:
                continue
    
    
     
     
